function [SpecimenListCombined,VoxInterestListCombined]=Step0_UserInputData(WhichGroups)
%   This function takes the desired specimens (Control, Compression, and/or
%   Tension) and returns the combined specimen list (in order of the
%   specified group) and, in the case of fatigue group specimens, the
%   appropriate VoxInterestList(s)

%----- Specimen List (assemble from "WhichGroups" input
%
%CT scan numbers  (Note: file system based on pre-stain scan #'s only)
% ordering below is CT Study #: 1291, 1292, 1293, 1294 (by line)

%check "WhichGroups" for Control ("Ctrl")
if (sum(strcmpi('Ctrl',WhichGroups))==1);
    SpecimenList.Ctrl={'8278';'8279';'8285';'8328';...
                       '8274';'8275';'8276';'8277';...
                       '8343';'8345';'8346';'8347';...
                       '8329';'8330';'8335'};
                % 1291  2;5;8;11
                % 1292  2;5;8;11
                % 1293  2;5;8;11
                % 1294  4;7;10
end

%check "WhichGroups" for Compression ("Comp")
if (sum(strcmpi('Comp',WhichGroups))==1);
    SpecimenList.Comp={'8000';'8001';'8002';...
                       '8197';'8262';'8263';'8264';...
                       '8174';'8176';'8184';'8189';...
                       '8195';'8196'};
                % 1291  1;4;7
                % 1292  1;4;7;10
                % 1293  1;4;7;10
                % 1294  8;11
end


%check "WhichGroups" for Tension ("Tens")
if (sum(strcmpi('Tens',WhichGroups))==1);
    SpecimenList.Tens={'8383';...
                       '8363';'8372';...
                       '8350';'8362';...
                       '8387'};
                % 1291  12
                % 1292  3;6
                % 1293  3;6
                % 1294  6
end

% %check "WhichGroups" for Tension ("Tens")
% if (sum(strcmpi('Tens',WhichGroups))==1);
%     SpecimenList.Tens={'8373';'8382';'8383';...
%                        '8363';'8372';...
%                        '8350';'8362';...
%                        '8387';'8385'};
%                 % 1291  3;9;12
%                 % 1292  3;6
%                 % 1293  3;6
%                 % 1294  6;9
% end

%Create a combined specimen list for all specimens of interest
SpecimenListCombined=[];
for i=1:length(WhichGroups)
    SpecimenListCombined=vertcat(SpecimenListCombined,SpecimenList.(WhichGroups{i}));
end              
%----- End Specimen List


%----- Voxel of Interest List
%
%The info below refers to the values contained in
%  VoxInterestListRow/Col/Slice variables
%--------------------------------------------------------------------------
%"Col" is Sagittal (X-value), "Row" is Coronal (Y-value), "Slice" is Transverse (Z-value)
%  from Analyze Volume Compare Module lower left corner (X,Y,Z) value based
%  on position of reference lines.

%NOTE: these values are referenced from (0,0,0) being attached to the lower
%  left corner of the first slice in the AVW files.  This is in contrast to
%  the CT (and Matlab) coordinate system, which has the Y zero attached to
%  the upper left corner of the first slice in AIM files.

%Therefore, to transform the Analyze coordinates into full ISQ CT
%  coordinate space, the AIM "X-position" and AIM "Z-position" must be
%  subtracted from the Analyze X and Z, respectively, and the AIM
%  "Y-position" must be subracted from (ISQ_DimY - AnalyzeY) where ISQ_DimY
%  is the row dimension of the ISQ file
%--------------------------------------------------------------------------
%
%check "WhichGroups" for Compression ("Comp")
if (sum(strcmpi('Comp',WhichGroups))==1);
    VoxInterestList.Col.Comp={174,'8000';
                              194,'8001';
                              256,'8002';
                              130,'8197';
                              137,'8262';
                              170,'8263';
                              223,'8264';
                              287,'8174';
                              136,'8176';
                              382,'8184';
                              381,'8189';
                              165,'8195';
                              225,'8196'};

    VoxInterestList.Row.Comp={182,'8000';
                              137,'8001';
                              120,'8002';
                              222,'8197';
                              261,'8262';
                              369,'8263';
                              383,'8264';
                              150,'8174';
                              305,'8176';
                              275,'8184';
                              217,'8189';
                              165,'8195';
                              142,'8196'};

    VoxInterestList.Slice.Comp={610,'8000';
                                160,'8001';
                                103,'8002';
                                242,'8197';
                                213,'8262';
                                124,'8263';
                                690,'8264';
                                995,'8174';
                                186,'8176';
                                402,'8184';
                                760,'8189';
                                986,'8195';
                                103,'8196'};
end


%check "WhichGroups" for Tension ("Tens")
if (sum(strcmpi('Tens',WhichGroups))==1)
    VoxInterestList.Col.Tens={128,'8383';
                              372,'8363';
                              379,'8372';
                              216,'8350';
                              136,'8362';
                              405,'8387'};

    VoxInterestList.Row.Tens={162,'8383';
                              168,'8363';
                              316,'8372';
                              134,'8350';
                              222,'8362';
                              206,'8387'};

    VoxInterestList.Slice.Tens={192,'8383';
                                1039,'8363';
                                1053,'8372';
                                131,'8350';
                                664,'8362';
                                1048,'8387'};
end

% %check "WhichGroups" for Tension ("Tens")
% if (sum(strcmpi('Tens',WhichGroups))==1)
%     VoxInterestList.Col.Tens={0,'8373';
%                               0,'8382';
%                               128,'8383';
%                               372,'8363';
%                               379,'8372';
%                               216,'8350';
%                               136,'8362';
%                               0,'8385';
%                               405,'8387'};
% 
%     VoxInterestList.Row.Tens={0,'8373';
%                               0,'8382';
%                               162,'8383';
%                               168,'8363';
%                               316,'8372';
%                               134,'8350';
%                               222,'8362';
%                               0,'8385';
%                               206,'8387'};
% 
%     VoxInterestList.Slice.Tens={0,'8373';
%                                 0,'8382';
%                                 192,'8383';
%                                 1039,'8363';
%                                 1053,'8372';
%                                 131,'8350';
%                                 664,'8362';
%                                 0,'8385';
%                                 1048,'8387'};
% end


%Create a combined VoxIntList list for all specimens of interest
VoxInterestListCombined.Col=[];
VoxInterestListCombined.Row=[];
VoxInterestListCombined.Slice=[];
if (sum(strcmpi('Comp',WhichGroups)) + sum(strcmpi('Tens',WhichGroups)) == 0)
    %no need to do anything here... simply leave the
    %VoxInterestListCombined as empty matrices
    
elseif (sum(strcmpi('Comp',WhichGroups)) + sum(strcmpi('Tens',WhichGroups)) == 1)
    if (sum(strcmpi('Comp',WhichGroups)) == 1)
        VoxInterestListCombined.Col=VoxInterestList.Col.Comp;
        VoxInterestListCombined.Row=VoxInterestList.Row.Comp;
        VoxInterestListCombined.Slice=VoxInterestList.Slice.Comp;
    elseif (sum(strcmpi('Tens',WhichGroups)) == 1)
        VoxInterestListCombined.Col=VoxInterestList.Col.Tens;
        VoxInterestListCombined.Row=VoxInterestList.Row.Tens;
        VoxInterestListCombined.Slice=VoxInterestList.Slice.Tens;
    end
    
elseif (sum(strcmpi('Comp',WhichGroups)) + sum(strcmpi('Tens',WhichGroups)) == 2)
    IdxComp=find(strcmpi('Comp',WhichGroups));
    IdxTens=find(strcmpi('Tens',WhichGroups));
    
    if (IdxComp < IdxTens)
        IdxNames={'Comp','Tens'};
    elseif (IdxTens < IdxComp)
        IdxNames={'Comp','Tens'};
    end
    
    for i=1:length(IdxNames)
        VoxInterestListCombined.Col=vertcat(VoxInterestListCombined.Col,VoxInterestList.Col.(IdxNames{i}));
        VoxInterestListCombined.Row=vertcat(VoxInterestListCombined.Row,VoxInterestList.Row.(IdxNames{i}));
        VoxInterestListCombined.Slice=vertcat(VoxInterestListCombined.Slice,VoxInterestList.Slice.(IdxNames{i}));
    end
else
    error('Too many fatigue loaded groups!')
end
%----- End Voxel of Interest List

end







