function Step1_Convert_Aim2Matlab

%----- Input the desired specimens
WhichGroups={'Ctrl';'Comp';'Tens'}; %Options: "'Ctrl'", "'Comp'", "'Tens'"
% note: the order here will determine the output variables order below

% Call "Step0_UserInputData" m-file to retrieve user-supplied data
[SpecimenList,VoxInterestList]=Step0_UserInputData(WhichGroups);

ObjInterestList={'GOBJ' 'GOBJ_PEEL10' 'PORES' 'lowMNRL' 'highMNRL' 'STAIN'};

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

StartTime=tic;
for s=1:length(SpecimenList)
    SpecimenNum=SpecimenList{s};
    Directory=strcat(SpecimenNum,'/');
    fprintf('\nSpecimen Number = %s\n',SpecimenNum)
    
    for o=1:length(ObjInterestList)

        Object=ObjInterestList{o};
        
        % Call sub-function to handle and save the data for each object
        ObjectFun(SpecimenNum,Directory,Object)
        
    end
    
    clear('SpecimenNum','Directory');
end
fprintf('\n\nProgram Execution Finished Successfully\n')
TotalTime=toc(StartTime);
TotalTimeMin=floor(TotalTime/60);
TotalTimeSec=round(((TotalTime/60)-TotalTimeMin)*60);
fprintf('Total time elapsed = %d min %d sec\n',TotalTimeMin,TotalTimeSec)
end %end of main function


% Sub-function "ObjectFun" handles and saves data for each object
%
%note: this subfunction was necessary because only 11 full specimens were
%able to be processed until, on the 12th specimen, there was an error
%saying the workspace variables were full--in spite of clearing all
%variables, so I decided to create a subfunction which has its own unique
%space (and only for the duration of each individual call to the 
%subfunction) and should hopefully not clog up the main workspace variables
function ObjectFun(SpecimenNum,Directory,Object)
    ObjTime=tic;

    if strcmpi(Object,'GOBJ')
        AIMname='_ALL_VOXELS_SEG_RUNL';
    elseif strcmpi(Object,'GOBJ_PEEL10')
        AIMname='_ALL_VOXELS_PEEL10_SEG_RUNL';
    elseif strcmpi(Object,'PORES')
        AIMname='_PORES_SEG_RUNL';
    elseif strcmpi(Object,'lowMNRL')
        AIMname='_MNRL_LOW20_SEG_RUNL';
    elseif strcmpi(Object,'highMNRL')
        AIMname='_MNRL_HIGH20_SEG_RUNL';
    elseif strcmpi(Object,'STAIN')
        AIMname='_POST_STAIN-MASK_SEG_RUNL';
    end

    ImgDir=strcat(Directory,'Images/');
    AIMfile=strcat(ImgDir,SpecimenNum,AIMname,'.AIM;1');

    fprintf('\t\tObject = %s ...',Object)

    AIMopen=fopen(AIMfile,'r','ieee-le');

    header=fread(AIMopen,32,'int32');

    DataOffset=sum(header(1:3))+4;% +4 accounts for 4 bytes that would otherwise be the first piece of info (data size) if read at int32 with the provided offset... but need to read data at uint8
    DataSize=header(4)-4;% similar to the +4 above, the -4 here accounts for 4 bytes (at uint8) that are at the very end of the data and are meaningless... don't know what the info is, but I know it is extraneous


    %pre defined types
    AIMtype=header(11);
    type_byt=1*2^16+1;
    type_int=2*2^16+2;
    type_lon=3*2^16+4;
    type_bin=21*2^16+1;
    type_charcmp=8*2^16+2;%=524290
    type_tri=13*2^16+1;
    if (AIMtype ~= type_charcmp)
        error('\n\nAIM file is not saved with run-length compression!')
    end

    Xpos=header(12);
    Ypos=header(13);
    Zpos=header(14);
    Xdim=header(15);
    Ydim=header(16);
    Zdim=header(17);
    AIM_PositionAndDimension={Xpos,Ypos,Zpos,'Position (x,y,z)';
        Xdim,Ydim,Zdim,'Dimension (x,y,z)'};
    save(strcat(ImgDir,SpecimenNum,'_AIM_PositionAndDimension'),'AIM_PositionAndDimension');


    fseek(AIMopen,DataOffset,'bof');

    AIMdata=fread(AIMopen,DataSize,'uint8');
    fclose(AIMopen);
    clear('AIMopen');

    Greater255=find((AIMdata>255));
    if (~isempty(Greater255))
        error('No values should be larger than 255! The run-length CT data should be read as uint8 and have only values <= 255!')
    end
    AIMdata=uint8(AIMdata);

    ImageSize=Xdim*Ydim*Zdim;

    VoxelNumber=0;
    SliceVoxelsMAX=Xdim*Ydim*1;
    SliceVoxels=0;
    SliceNum=0;
    SavedState=0;
    SaveCount=0;
    if (SliceVoxelsMAX <= intmax('int32'))
        LinearIndRUNL=int32([]);
    else
        LinearIndRUNL=[];
    end
    StatusCheck=0;
    RowNow=0;
    for i=1:2:(DataSize-1)

        if ((AIMdata(i))~=0)%Note: AIMdata(i)=valueNEW
            StatusCheck=1;%LinearIndRUNL needs to be recorded (StatusCheck=1)

            Start=SliceVoxels+1;
            ExtraRunLength=(double(AIMdata(i+1))-1);%Note: double(AIMdata(i+1)=CountNEW  %Note: "ExtraRunLength"... so if only 1 voxel, then Start and 0, or if 2 consecutive voxels, then Start and 1, etc.
            %NOTE: the CT indexes row-wise, from upper left moving
            %to lower right!  So when using the CT index in Matlab,
            %the result will be a transpose of the original CT
            %data, so a transpose() operation will need to be
            %performed on the matlab data
        end

        SliceVoxels=SliceVoxels+(double(AIMdata(i+1)));%Note: double(AIMdata(i+1))=Count
        VoxelNumber=VoxelNumber+(double(AIMdata(i+1)));%Note: double(AIMdata(i+1))=Count

        if ((SliceVoxels<SliceVoxelsMAX) && (VoxelNumber<ImageSize))
            if (i==(DataSize-1)) %this is the end of the AIMdata variable!
                error('This case should not happen! Check the data! Should have reached both SliceVoxelsMAX and ImageSize at this point!')
            end

            if (StatusCheck==1)
                RowNow=RowNow+1;
                LinearIndRUNL(RowNow,:)=[Start ExtraRunLength];%these non-zero rows ("Start") are the linear indices of non-zero voxels and the "ExtraRunLengths" begin after and do not include the Starting voxel location
                %NOTE: remember that these are ordered row-wise per the CT,
                %so the image will be transposed if viewed with Matlab!

                StatusCheck=0;%LinearIndRUNL has been recorded (StatusCheck=0)
            end

        else
            SliceNum=SliceNum+1;
            SaveCount=SaveCount+1;

            NextSliceVoxels=SliceVoxels-SliceVoxelsMAX;

            if (StatusCheck==1)
                if (NextSliceVoxels~=0)
                    ExtraRunLength=ExtraRunLength-NextSliceVoxels;
                    StatusCheck2=1;%LinearIndRUNL for next slice needs to be recorded
                else
                    StatusCheck2=0;%No LinearIndRUNL for next slice needs to be recorded yet since NextSliceVoxels==0
                end

                RowNow=RowNow+1;
                LinearIndRUNL(RowNow,:)=[Start ExtraRunLength];%these non-zero rows ("Start") are the linear indices of non-zero voxels and the "ExtraRunLengths" begin after and do not include the Starting voxel location
                %NOTE: remember that these are ordered row-wise per the CT,
                %so the image will be transposed if viewed with Matlab!

                if (StatusCheck2==1)
                    StatusCheck=1;%LinearIndRUNL (of next slice) needs to be recorded (StatusCheck=1)
                    Start=0;%this is faster than clear('Start') :o)
                    ExtraRunLength=0;%this is faster than clear('ExtraRunLength') :o)
                else
                    StatusCheck=0;%LinearIndRUNL has been recorded (StatusCheck=0)
                end
            end

            SliceLinIndName=strcat('LinearIndexRUNL_',SpecimenNum,'_',Object,'_Slice',num2str(SliceNum));
            eval([SliceLinIndName ' = LinearIndRUNL;'])

            clear('SliceVoxels');
            RowNow=0;
            if (SliceVoxelsMAX <= intmax('int32'))
                LinearIndRUNL=int32([]);%reset LinearIndRUNL
            else
                LinearIndRUNL=[];%reset LinearIndRUNL
            end

            if (NextSliceVoxels==0)
                SliceVoxels=0;
            else
                SliceVoxels=NextSliceVoxels;
                %don't need to update "VoxelNumber" here since it was updated appropriately prior to getting into this loop region

                if (StatusCheck==1)
                    Start=1;
                    ExtraRunLength=NextSliceVoxels-1;

                    RowNow=RowNow+1;
                    LinearIndRUNL(RowNow,:)=[Start ExtraRunLength];%these non-zero rows ("Start") are the linear indices of non-zero voxels and the "ExtraRunLengths" begin after and do not include the Starting voxel location
                    %NOTE: remember that these are ordered row-wise per the CT,
                    %so the image will be transposed if viewed with Matlab!

                    StatusCheck=0;%LinearIndRUNL has been recorded (StatusCheck=0)
                end
            end

            clear('NextSliceVoxels','SliceLinIndName');

            if ((SaveCount==100) || (SliceNum==Zdim))

                NameFile=strcat(ImgDir,SpecimenNum,'_',Object,'_LinearIndexRUNL.mat');%e.g.,'6780_GOBJ_LinearIndexRUNL.mat';
                if (SavedState==0)
                    save(NameFile,'-regexp','LinearIndexRUNL_\d+_','-v7.3')%-v7.3 .mat file for compatibility with the 'matfile' function for loading and saving (even partial variables)
                    SavedState=1;
                else
                    save(NameFile,'-regexp','LinearIndexRUNL_\d+_','-append','-v7.3')%-v7.3 .mat file for compatibility with the 'matfile' function for loading and saving (even partial variables)
                end

                clear('NameFile');
                clear('-regexp','LinearIndexRUNL_\d+_');
                %the + sign means "multiple numbers possible" and an implicit *
                %character for "all" that match after the regexp seems to
                %be the case so in my head I would write LinearIndexRUNL_\d+_*,
                %but the * is implied by regexp apparently

                SaveCount=0;
            end
            Start=0;%this is faster than clear('Start') :o)
            ExtraRunLength=0;%this is faster than clear('ExtraRunLength') :o)
        end
    end

    Duration=toc(ObjTime);
    DurationMin=floor(Duration/60);
    DurationSec=round(((Duration/60)-DurationMin)*60);
    fprintf(' Complete!  Duration = %d min %d sec\n',DurationMin,DurationSec)
    clear('ObjTime','Duration','DurationMin','DurationSec');
end

