function Step2_STAIN_Peel_AndOr_ArtifactRemoval

%----- Input the desired specimens
WhichGroups={'Ctrl','Comp','Tens'}; %Options: "'Ctrl'", "'Comp'" or "'Tens'"
% note: the order here will determine the output variables order below

% Call "Step0_UserInputData" m-file to retrieve user-supplied data
[SpecimenList,VoxInterestList]=Step0_UserInputData(WhichGroups);

ObjInterestList={'STAIN'};

PeelDecision=1;%set "PeelDecision" to 1=on or 0=off to enable/disable peeling of the object(s) according to "PeelAmnt" below
PeelAmnt=10;%number of voxels removed from the GOBJ surface (used to determine % penetration and peel if desired!)

PcentNum=0;%percentage (whole number % here... decimal conversion later) of voxels of each cluster that must penetrate into the inner GOBJ region or else the stain cluster will be deleted (NOTE: set to a value of "0" to disable %inclusion criteria)
ConnectivityNum=[];%pixel connectivity for bwconncomp... set to [] if desire default connectivity (i.e., 2D=8, 3D=26)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

StartTime=tic;
for s=1:length(SpecimenList)
    SpecimenNum=SpecimenList{s};
    Directory=strcat(SpecimenNum,'/');
    fprintf('\nSpecimen Number = %s\n',SpecimenNum)
    
    
    %START loading "InnerGOBJ" (e.g., GOBJ_PEEL10)
    fprintf('\tLoading "InnerGOBJ" ...')
    
    LinearIndRUNL_file_InGOBJ=strcat(Directory,'Images/',SpecimenNum,'_GOBJ_PEEL',num2str(PeelAmnt),'_LinearIndexRUNL.mat');
    
    DimsXYZ=open(strcat(Directory,'Images/',SpecimenNum,'_AIM_PositionAndDimension.mat'));
    SpecimenDims=cell2mat(DimsXYZ.AIM_PositionAndDimension(2,1:3));
    
    SliceVoxelsMAX=SpecimenDims(1)*SpecimenDims(2);%Xdim*Ydim;
    
    % call sub-function "LoadLinearIndRUNL"
    GOBJ_Object=strcat('GOBJ_PEEL',num2str(PeelAmnt));
    [InnerGOBJ]=LoadLinearIndRUNL(LinearIndRUNL_file_InGOBJ,SpecimenDims,SpecimenNum,GOBJ_Object);
    
    InnerGOBJ=logical(InnerGOBJ);
    %Note: I do not perform a transpose() operation on the variable
    %"InnerGOBJ" since it is not necessary for this artifact removal and
    %peel operation, as long as the below object(s) are also not transposed!
    
    fprintf(' Complete!\n')
    %FINISHED loading "InnerGOBJ" (e.g., GOBJ_PEEL10)
    
    
    for o=1:length(ObjInterestList)
        ObjTime=tic;
        
        Object=ObjInterestList{o};
        
        ImgDir=strcat(Directory,'Images/');
        
        fprintf('\t\tObject = %s ...',Object)
        
        LinearIndRUNL_file=strcat(ImgDir,SpecimenNum,'_',Object,'_LinearIndexRUNL.mat');
        % call sub-function "LoadLinearIndRUNL"
        [ALLslices]=LoadLinearIndRUNL(LinearIndRUNL_file,SpecimenDims,SpecimenNum,Object);
        
        ALLslices=logical(ALLslices);
        %Note: I do not perform a transpose() operation on the variable
        %"ALLslices" since it is not necessary for this artifact removal
        %and peel operation, as long as the above "InnerGOBJ" is also not
        %transposed!
        
        if (PcentNum > 0) %check to see if an Artifact Removal is desired; if not, i.e., PcentNum==0, then skip this section
            if (isempty(ConnectivityNum))
                RegionPropsInfo=regionprops(ALLslices,'PixelList');
                if (length(size(ALLslices))==3)
                    ConnectivityNum=26;%default 3D connectivity
                elseif (length(size(ALLslices))==2)
                    ConnectivityNum=8;%default 2D connectivity
                end
            else
                BWconnectInfo=bwconncomp(ALLslices,ConnectivityNum);
                RegionPropsInfo=regionprops(BWconnectInfo,'PixelList');
            end
            
            NumClustKilled=0;%will be the number of clusters that were removed due to not existing inside the InnerGOBJ region
            KillClustVol=0;%will be the volume [voxels] removed due to clusters not existing inside the InnerGOBJ region
            for Clust=1:length(RegionPropsInfo(:,1))%this is the number of ConnectedComponents (clusters)

                [ColVxl]=RegionPropsInfo(Clust,1).PixelList(:,1);%X
                [RowVxl]=RegionPropsInfo(Clust,1).PixelList(:,2);%Y
                [SliceVxl]=RegionPropsInfo(Clust,1).PixelList(:,3);%Z

                vxl=0;
                FoundFlag=0;
                while ((vxl<length(ColVxl)) && (FoundFlag<(round((PcentNum/100)*length(ColVxl)))))%i.e., kill if < X% of voxels in cluster penetrate InnerGOBJ
                    vxl=vxl+1;

                    RowVxlNOW=RowVxl(vxl);
                    ColVxlNOW=ColVxl(vxl);
                    SliceVxlNOW=SliceVxl(vxl);
                    if (InnerGOBJ(RowVxlNOW,ColVxlNOW,SliceVxlNOW))%==1)%don't need to compare it to anything since value inside InnerGOBJ is alread a logical 1 or 0!
                        FoundFlag=FoundFlag+1;%actuated each time a voxel from the current cluster penetrates the InnerGOBJ region. The entire cluster is safe if, e.g., >"PcentNum"% of cluster voxels meet this criterion and will not be deleted--move to next cluster at that point
                    end

                    RowVxlNOW=0;
                    ColVxlNOW=0;
                    SliceVxlNOW=0;
                end

                if ((FoundFlag<(round((PcentNum/100)*length(ColVxl)))) && (vxl==length(ColVxl)))%i.e., if have searched all voxels within current cluster and less than "PcentNum"% lie inside InnerGOBJ region, then kill all voxels of current cluster
                    %i.e., enter this loop to "kill" (remove) all voxels of stain clusters that
                    %did not penetrate into the inner GOBJ region

                    for KillVxl=1:1:length(ColVxl)
                        RowKillVxl=RowVxl(KillVxl);
                        ColKillVxl=ColVxl(KillVxl);
                        SliceKillVxl=SliceVxl(KillVxl);

                        ALLslices(RowKillVxl,ColKillVxl,SliceKillVxl)=0;

                        RowKillVxl=0;
                        ColKillVxl=0;
                        SliceKillVxl=0;
                    end

                    NumClustKilled=NumClustKilled+1;
                    KillClustVol=KillClustVol+length(ColVxl);%there are "length(ColVxl)" number of voxels in each cluster of voxels, i.e., regionprops.Area=length(PixelList(:,1))
                end

                ColVxl=0;
                RowVxl=0;
                SliceVxl=0;
            end
        end
        
        %Perform optional peel operation (peel option set by "PeelDecision"
        %at top of this file
        if (PeelDecision==1)
            ALLslicesPeeled=logical(zeros(size(ALLslices),'int8'));
            for slicenow=1:1:size(ALLslices,3)
                ALLslicesPeeled(:,:,slicenow)=InnerGOBJ(:,:,slicenow).*ALLslices(:,:,slicenow);%this command peels "ALLslices", i.e., sets to 0 any voxel that is not contained in the InnerGOBJ region
            end
            
            ALLslicesSave=reshape(ALLslicesPeeled,(SliceVoxelsMAX*SpecimenDims(3)),1);
            %Note: this command puts the data back into a column, as if it had
            %been read from the CT,i.e., row-wise data down the column
            
            clear('ALLslicesPeeled');
        else
            ALLslicesSave=reshape(ALLslices,(SliceVoxelsMAX*SpecimenDims(3)),1);
            %Note: this command puts the data back into a column, as if it had
            %been read from the CT,i.e., row-wise data down the column
            
            clear('ALLslices');
        end
        
        
        %call sub-function "Save_RUNL"
        Save_RUNL(ALLslicesSave,ImgDir,SpecimenDims,SpecimenNum,Object,PeelDecision,PeelAmnt,PcentNum)
        
        
        Duration=toc(ObjTime);
        DurationMin=floor(Duration/60);
        DurationSec=round(((Duration/60)-DurationMin)*60);
        fprintf(' Complete!  Duration = %d min %d sec\n',DurationMin,DurationSec)
        clear('ObjTime','Duration','DurationMin','DurationSec');
        
        if ((PeelDecision==1) && (PcentNum>0))
            fprintf('\t\t\tNumber of clusters killed = %d of %d (Total volume removed = %d voxels)\n',NumClustKilled,Clust,KillClustVol)
            fprintf('\n\t\tNOTE: %s object was peeled by %d voxels\n\n',Object,PeelAmnt)
        elseif  ((PeelDecision==1) && (PcentNum==0))
            fprintf('\t\t\tNOTE: Artifact removal was NOT performed for %s object\n',Object)
            fprintf('\n\t\tNOTE: %s object was peeled by %d voxels\n\n',Object,PeelAmnt)
        elseif (PeelDecision==0)
            fprintf('\t\t\tNumber of clusters killed = %d of %d (Total volume removed = %d voxels)\n',NumClustKilled,Clust,KillClustVol)
            fprintf('\n\t\tNOTE: %s object has NOT been peeled\n\n',Object)
        end
        
        clear('Object','ImgDir','LinearIndRUNL_file','SliceVoxelsMAX',...
            'ALLslices','ALLslicesPeeled','ALLslicesSave',...
            'RegionPropsInfo','SliceVoxels','SliceNum','SavedState');
    end
    
    clear('SpecimenNum','Directory','LinearIndRUNL_file_InGOBJ',...
        'InnerGOBJ','SliceCount');
end
fprintf('\n\nProgram Execution Finished Successfully\n')
TotalTime=toc(StartTime);
TotalTimeMin=floor(TotalTime/60);
TotalTimeSec=round(((TotalTime/60)-TotalTimeMin)*60);
fprintf('Total time elapsed = %d min %d sec\n',TotalTimeMin,TotalTimeSec)
end %end of main function


% Sub-function "LoadLinearIndRUNL"
%
function [OutputDataMatrix]=LoadLinearIndRUNL(Input_LinearIndRUNL,Dim_XYZ,SpecimenNum,ObjectNow)
    LinearInd_ALL=load(Input_LinearIndRUNL,'-mat');
    
    SliceVoxelsMAX=Dim_XYZ(1)*Dim_XYZ(2);%Xdim*Ydim;
    
    %"GaussSupportOffset" is used to account for slices with no voxels at
    %the first and last few slice(s) of each Object based on the Gauss
    %support value used for filtering on the CT system analysis
    if (strcmpi(ObjectNow,'STAIN') == 1)
        GaussSupportOffset=3;
    else
        GaussSupportOffset=1;
    end
    
    OutputDataMatrix=zeros([Dim_XYZ(1) Dim_XYZ(2) Dim_XYZ(3)],'int8');%[Xdim Ydim Zdim]
    for slice=(1+GaussSupportOffset):1:(Dim_XYZ(3)-GaussSupportOffset)
        CurrentSlice=strcat('LinearIndexRUNL_',SpecimenNum,'_',ObjectNow,'_Slice',num2str(slice));
        SliceData=LinearInd_ALL.(CurrentSlice);
        LinearInd_ALL=rmfield(LinearInd_ALL,CurrentSlice);%this clears the single, LinearIndexRUNL file that was just assigned to the "SliceData" variable in the previous line of code
        
        LinearInd=zeros(SliceVoxelsMAX,1,'int8');
        if (isempty(SliceData) == 0) %"SliceData" must be non-empty to enter this loop
            for Row=1:1:length(SliceData(:,1))
                %{
                    For the statement below:
                        SliceData(Row,1) = linear index of starting voxel location
                        SliceData(Row,2) = number of extra voxels from the
                                            starting voxel location
                %}
                LinearInd(SliceData(Row,1):1:(SliceData(Row,1)+SliceData(Row,2)),1)=1;
            end
        
            OutputDataMatrix(:,:,slice)=reshape(LinearInd,Dim_XYZ(1),Dim_XYZ(2));
            %NOTE: the reshape command is correct as written to say Xdim,Ydim
            %since CT reads row-wise and Matlab orders column-wise, so the
            %shape is just trasposed, but the data is fine... just make sure to
            %also compare transposed images later in this code, rather than, e.g., a
            %CT image and a Matlab transposed image.
        end
        
        clear('CurrentSlice','SliceData')
    end
    
    clear('LinearInd_ALL')
end




% Sub-function "Save_RUNL"
%
function Save_RUNL(Input_Image,ImgDir,SpecimenDims,SpecimenNum,Object,PeelDecision,PeelAmnt,PcentNum)
    SliceVoxelsMAX=SpecimenDims(1)*SpecimenDims(2);

    SavedState=0;
    SaveCount=0;
    LoopCount=0;
    for SliceNum=1:1:SpecimenDims(3)
        SaveCount=SaveCount+1;
        LoopCount=LoopCount+1;
        ReadData=(1+SliceVoxelsMAX*(LoopCount-1)):1:(SliceVoxelsMAX*LoopCount);%indices to be used from "ALLslicesSave" data for current slice
        SliceData=Input_Image(ReadData,1);

        NonZeroClust=regionprops(SliceData,'PixelIdxList');

        if (SliceVoxelsMAX <= intmax('int32'))
            LinearIndRUNL=zeros([length(NonZeroClust(:,1)) 2],'int32');
        else
            LinearIndRUNL=zeros(length(NonZeroClust(:,1)),2);
        end

        for ClustNow=1:length(NonZeroClust(:,1))
            Start=NonZeroClust(ClustNow,1).PixelIdxList(1);
            ExtraRunLength=(NonZeroClust(ClustNow,1).PixelIdxList(end))-Start;
            LinearIndRUNL(ClustNow,:)=[Start ExtraRunLength];

            Start=0;%faster than "clear(Start)" :o) see Matlab "profiler" for info on each specific m-file as it runs
            ExtraRunLength=0;%faster than "clear(ExtraRunLength)" :o)
        end

        if ((PeelDecision==1) && (PcentNum>0))
            SliceLinIndName=strcat('LinearIndexRUNL_',SpecimenNum,'_',Object,'_ArtfctRemvd',num2str(PcentNum),'p_Peel',num2str(PeelAmnt),'_Slice',num2str(SliceNum));
        elseif  ((PeelDecision==1) && (PcentNum==0))
            SliceLinIndName=strcat('LinearIndexRUNL_',SpecimenNum,'_',Object,'_Peel',num2str(PeelAmnt),'_Slice',num2str(SliceNum));
        elseif (PeelDecision==0)
            SliceLinIndName=strcat('LinearIndexRUNL_',SpecimenNum,'_',Object,'_ArtfctRemvd',num2str(PcentNum),'p_Slice',num2str(SliceNum));
        end
        eval([SliceLinIndName ' = LinearIndRUNL;'])
        clear('SliceLinIndName');

        if ((SaveCount==100) || (SliceNum==SpecimenDims(3)))

            if ((PeelDecision==1) && (PcentNum>0))
                NameFile=strcat(ImgDir,SpecimenNum,'_',Object,'_ArtfctRemvd_Peel',num2str(PeelAmnt),'_LinearIndexRUNL.mat');
            elseif  ((PeelDecision==1) && (PcentNum==0))
                NameFile=strcat(ImgDir,SpecimenNum,'_',Object,'_Peel',num2str(PeelAmnt),'_LinearIndexRUNL.mat');
            elseif (PeelDecision==0)
                NameFile=strcat(ImgDir,SpecimenNum,'_',Object,'_ArtfctRemvd_LinearIndexRUNL.mat');
            end

            if (SavedState==0)
                save(NameFile,'-regexp','LinearIndexRUNL_\d+_','-v7.3')%-v7.3 .mat file for compatibility with the 'matfile' function for loading and saving (even partial variables)
                SavedState=1;
            else
                save(NameFile,'-regexp','LinearIndexRUNL_\d+_','-append','-v7.3')%-v7.3 .mat file for compatibility with the 'matfile' function for loading and saving (even partial variables)
            end

            clear('NameFile');
            clear('-regexp','LinearIndexRUNL_\d+_');
            %the + sign means "multiple numbers possible" and an implicit *
            %character for "all" that match after the regexp seems to
            %be the case so in my head I would write LinearIndexRUNL_\d+_*,
            %but the * is implied by regexp apparently

            SaveCount=0;
        end

        ReadData=0;
        SliceData=0;%faster than "clear(SliceData)" :o)
        clear('NonZeroClust')
    end
end







