function Step3_TPCF_5pcentStain_Ctrl(InputVar)

%----- Input the desired specimens
WhichGroups={'Ctrl'}; %Options: "'Ctrl'" %This code set up to handle Ctrl only since no FailSite cluster assosicated w/ Ctrl specimens...
% note: the order here will determine the output variables order below

% Call "Step0_UserInputData" m-file to retrieve user-supplied data
[SpecimenList,VoxInterestList]=Step0_UserInputData(WhichGroups);

ObjInterestList={'GOBJ' 'PORES' 'lowMNRL' 'highMNRL' 'GOBJ_EaClustRemvdDV' 'STAIN_EaClustRemvd'};%"EaClustRemvd" = each current cluster removed, i.e., the current PDF analysis origin cluster

NUMspec=length(SpecimenList); %change this value to match number of specimens in code
NUMobjINT=length(ObjInterestList); %change this value to match number of objects of interest in code
s=InputVar-(NUMspec*floor((InputVar-1)/NUMspec)); %specimen number
o=ceil(InputVar/NUMspec); %object number

NumSlicesEval=300; %enter the number of slices to be evaluated +- from each vxl of interest (300 vxls = specimen diameter)

PcentEvalNum=5; %enter percentage of voxels in each stain cluster to evaluate as the origin for TPCF
PcentEval=PcentEvalNum/100; %decimal form of PcentEvalNum
VoxSkip=1/PcentEval;

FullISQdim_XYZ=[512 512 1166]; %used for failure site cluster identification later in code
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

if ((length(VoxInterestList.Row)~=length(VoxInterestList.Col))||(length(VoxInterestList.Row)~=length(VoxInterestList.Slice)))
    error('Number of elements of VoxInterestList.Row/Col/Slice must be equal!')
end

StartTime=tic;
% for s=1:length(SpecimenList)
    SpecimenNum=SpecimenList{s};
    Directory=strcat(SpecimenNum,'/');
    fprintf('\nSpecimen Number = %s\n',SpecimenList{s})
    
    PosAndDimsXYZ=open(strcat(Directory,'Images/',SpecimenNum,'_AIM_PositionAndDimension.mat'));
    Pos_XYZ=cell2mat(PosAndDimsXYZ.AIM_PositionAndDimension(1,1:3));
    Dim_XYZ=cell2mat(PosAndDimsXYZ.AIM_PositionAndDimension(2,1:3));
    clear('PosAndDimsXYZ');
    
    SliceVoxelsMAX=Dim_XYZ(1)*Dim_XYZ(2);%Xdim*Ydim;
    
%     MAXdist=ceil(sqrt(sum(Dim_XYZ(:).^2)));%This is the absolute max distance possible given the specimen image dimensions
    MAXdist=ceil(sqrt(sum([Dim_XYZ(1) Dim_XYZ(2) NumSlicesEval].^2)));%This is the max distance possible with the given 'NumSlicesEval'
    if (MAXdist > intmax('int16'))
        error('Need to change the ''int16'' class of the below "DistanceObject" variables! (2 instances of ''int16''! (recommend ''double''))');
    end


    %START loading "STAIN_Peel10"-------------------------------------
    LoadStainStart=tic;
    fprintf('\tLoading "STAIN_Peel10" ...')
    
    ObjectNow='STAIN_Peel10';
    LinearIndRUNL_file_STAIN_ArtfctRemvd=strcat(Directory,'Images/',SpecimenNum,'_',ObjectNow,'_LinearIndexRUNL.mat');
    % call sub-function "LoadLinearIndRUNL"
    [STAIN_ArtfctRemvd]=LoadLinearIndRUNL(LinearIndRUNL_file_STAIN_ArtfctRemvd,Dim_XYZ,SpecimenNum,ObjectNow);
    
    STAIN_ArtfctRemvd=logical(STAIN_ArtfctRemvd);
    
    LoadSec=round(toc(LoadStainStart));
    fprintf(' Complete!  Duration = %d sec\n',LoadSec)
    %FINISHED loading "STAIN_Peel10"----------------------------------
    
    
    %Find clusters of stain, label the clusters, and find their voxel
    %locations in an image volume
    ConnectedStain=bwconncomp(STAIN_ArtfctRemvd);
    LabelMatx=labelmatrix(ConnectedStain);
    ConnStainInfo=regionprops(LabelMatx,'PixelList');
    clear('LabelMatx');
    
    %There is no Failure Site stain cluster for control specimens!
    
    
%     for o=1:length(ObjInterestList)
        ObjTime=tic;
        
        Object=ObjInterestList{o};
        
        fprintf('\t\tObject = %s ...\n',Object)
        
        %Load and find RowCol info for all non-"*ClustRemvd*" objects.  For
        %object "GOBJ_EaClustRemvd" the GOBJ_all matrix must be loaded and
        %saved, so that the GOBJ_Temp matrix can be created from the
        %GOBJ_all matrix during each new cluster "for" loop iteration below
        if (isempty(regexpi(Object,'EaClustRemvd')) == 1)%catch all non-'EaClustRemvd' object cases
            clear('STAIN_ArtfctRemvd','ConnectedStain');
            
            %START loading "Object" and find "RowCol" nonzero voxels-----------
            LinearIndRUNL_file_Object=strcat(Directory,'Images/',SpecimenNum,'_',Object,'_LinearIndexRUNL.mat');
            
            [RowCol,RowCol_LOWslice,RowCol_HIGHslice]=RowCol_FromLinearIndRUNL(LinearIndRUNL_file_Object,Dim_XYZ,SpecimenNum,Object);
            %FINISHED loading "Object" and find "RowCol" nonzero voxels--------% call sub-function "RowCol_FromLinearIndRUNL"
            
        elseif (isempty(regexpi(Object,'GOBJ_EaClustRemvd')) == 0)%catch 'GOBJ_EaClustRemvd*' object cases
            clear('STAIN_ArtfctRemvd');
            ObjectLoad='GOBJ';
            
            %START loading "Object" and find "RowCol" nonzero voxels-----------
            LinearIndRUNL_file_Object=strcat(Directory,'Images/',SpecimenNum,'_',ObjectLoad,'_LinearIndexRUNL.mat');
            
            [GOBJ_all]=LoadLinearIndRUNL(LinearIndRUNL_file_Object,Dim_XYZ,SpecimenNum,ObjectLoad);
            %FINISHED loading "Object" and find "RowCol" nonzero voxels--------% call sub-function "RowCol_FromLinearIndRUNL"
            clear('ObjectLoad');
        end
        
        %initialize ALL_DistObj cell array
        ALL_DistObj_DistObj=zeros(MAXdist,length(ConnStainInfo(:,1)));
        ALL_DistObj_NumConnComp=zeros(length(ConnStainInfo(:,1)),1);
        ALL_DistObj=cell(length(ConnStainInfo(:,1)),2);
        ALL_DistObj(:,1)=num2cell(ALL_DistObj_DistObj,1)';
        ALL_DistObj(:,2)=num2cell(ALL_DistObj_NumConnComp,2);
        clear('ALL_DistObj_DistObj','ALL_DistObj_NumConnComp');
        
        %initialize FailSite_DistObj cell array
        FailSite_DistObj_DistObj=zeros(MAXdist,1);
        FailSite_DistObj_NumConnComp=zeros(1,1);
        FailSite_DistObj_ConnComp=zeros(1,1);
        FailSite_DistObj=cell(1,3);
        FailSite_DistObj{1,1}=FailSite_DistObj_DistObj;
        FailSite_DistObj{1,2}=FailSite_DistObj_NumConnComp;
        FailSite_DistObj{1,3}=FailSite_DistObj_ConnComp;
        clear('FailSite_DistObj_DistObj','FailSite_DistObj_NumConnComp','FailSite_DistObj_ConnComp');
        
        matlabpool open 8 % max num cores allowed on CRC is 8
        for c=1:length(ConnStainInfo(:,1)) %loop over each stain cluster
            fprintf('clust:%d Y:%d M:%d D:%d H:%d M:%d S:%d\n',c,fix(clock))
            
            DistObj=zeros(MAXdist,1);%this needs to be left as double-precision since could have lots of voxels at each distance!
            
            PxlListLength=length(ConnStainInfo(c,1).PixelList(:,1));
            COLtemp=ConnStainInfo(c,1).PixelList(round(1:VoxSkip:PxlListLength),1);%extract "PcentEvalNum" percentage of all voxels, starting with first, e.g., PcentEvalNum=5pcent, then every 20th voxel
            ROWtemp=ConnStainInfo(c,1).PixelList(round(1:VoxSkip:PxlListLength),2);
            SLICEtemp=ConnStainInfo(c,1).PixelList(round(1:VoxSkip:PxlListLength),3);
            
            %Catch the "*ClustRemvd*" object cases since these objects need
            %to be updated and have the current cluster's voxels set to 0
            %each pass through this loop--note that all non-"*ClustRemvd*"
            %objects have already been taken care of (RowCol info found)
            %and do not need anything changed, so nothing happens to these
            %objections at this "if" statement.
            if (isempty(regexpi(Object,'GOBJ_EaClustRemvdDV')) == 0)%catch 'GOBJ_EaClustRemvdDV' object case
                ConnComp_remv_vxls=ConnectedStain.PixelIdxList{1,c};%indices of all voxels in the current stain cluster
                
                GOBJ_Temp=GOBJ_all;%initialize to the full set of all clusters
                GOBJ_Temp(ConnComp_remv_vxls)=0;%remove the current cluster of voxels from the full set
                clear('ConnComp_remv_vxls');
                
                % call sub-function "RowCol_FromMatrix"
                [RowCol,RowCol_LOWslice,RowCol_HIGHslice]=RowCol_FromMatrix(GOBJ_Temp,Dim_XYZ,Object);
                
            elseif (isempty(regexpi(Object,'STAIN_EaClustRemvd')) == 0)%catch 'STAIN_EaClustRemvd' object case
                ConnComp_remv_vxls=ConnectedStain.PixelIdxList{1,c};%indices of all voxels in the current stain cluster
                
                STAIN_ArtfctRemvdTemp=STAIN_ArtfctRemvd;%initialize to the full set of all clusters
                STAIN_ArtfctRemvdTemp(ConnComp_remv_vxls)=0;%remove the current cluster of voxels from the full set
                clear('ConnComp_remv_vxls');
                
                % call sub-function "RowCol_FromMatrix"
                [RowCol,RowCol_LOWslice,RowCol_HIGHslice]=RowCol_FromMatrix(STAIN_ArtfctRemvdTemp,Dim_XYZ,Object);
            end
            
            parfor slice=RowCol_LOWslice:RowCol_HIGHslice
                %could choose instead to base slice range above on actual
                %STAIN slices, but current way does not affect results and
                %allows greater flexibility for future changes or if
                %different stain volume sizes were desired relative to
                %RowCol slices
                
                rows=single(RowCol(slice).Rows);%double(RowCol(slice).Rows);
                cols=single(RowCol(slice).Cols);%double(RowCol(slice).Cols);
                
                if (isempty(rows) == 0) %if no data, then skip this slice instance
                    
                    VxlIdxs=find(bitand(SLICEtemp>=(slice-NumSlicesEval),SLICEtemp<=(slice+NumSlicesEval)));%these stain voxels fit within the NumSlicesEval criteria
                    if (isempty(VxlIdxs) == 0) %this confirms that there were voxels from the current stain cluster that fit the NumSlicesEval criteria... if none, then do nothing for this slice instance

                        %calculate #columns each iteration based on fixed #rows of DistanceObjectNOW and 'int16' data type, i.e., 2-bytes per entry
                        NumDistObjCols=floor((20e6)/(2*length(rows))); %MaxMemory[bytes]/(2BytesPerEntry*#rows)
                        MemLoopIters=length(VxlIdxs)/NumDistObjCols; %number of iterations to go through all of necessary VxlIdxs
                        if ((MemLoopIters-floor(MemLoopIters))==0) %no remainder, even number of column increments to reach length(VxlIdxs)
                            MemLoopCols=NumDistObjCols.*ones(MemLoopIters,1);
                        else %a remainder exists, so tack it on to the end of the MemLoopCols vector
                            MemLoopCols=vertcat(NumDistObjCols.*ones(floor(MemLoopIters),1),length(VxlIdxs)-NumDistObjCols*floor(MemLoopIters));
                        end

                        StartVxl=1;
                        for MemLoop=1:length(MemLoopCols)
                            DistanceObjectNOW=zeros(length(rows),MemLoopCols(MemLoop),'int16');
                            FinishVxl=(StartVxl-1)+MemLoopCols(MemLoop);
                            for vxl=StartVxl:FinishVxl
                                COL=COLtemp(VxlIdxs(vxl),1);
                                ROW=ROWtemp(VxlIdxs(vxl),1);
                                SLICE=SLICEtemp(VxlIdxs(vxl),1);

                                DistanceObjectNOW(:,vxl-StartVxl+1)=sqrt((rows-ROW).^2 + (cols-COL).^2 + (slice-SLICE)^2); %no int16() needed since putting in pre-defined DistanceObjectNOW with class 'int16'

                                COL=[]; ROW=[]; SLICE=[]; 
                            end %end of loop over voxels of current stain cluster that satisfy NumSlicesEval criteria

                            NumDistObj=regionprops(DistanceObjectNOW,'Area');%this finds the number of voxels ("Area") at any distance, the result is in a structure array
                            [~,Distances,NumVoxAtDist]=find([NumDistObj.Area]);%NOTE: the ~ character means I want to ignore this returned value since find([NumDistObj.Area]) produces a row vector, not a matrix
                            DistObjTemp=zeros(MAXdist,1);
                            DistObjTemp(Distances,1)=NumVoxAtDist;
                            DistObj=DistObj+DistObjTemp;
                            %NOTE: with the method above for calculating and then compiling
                            %distances, there is NO NEED to worry about the single position
                            %where distance can be calculated as "0"... this is because
                            %regionprops() disregards 0's anyway! :o)

                            StartVxl=FinishVxl+1;

                            NumDistObj=[]; Distances=[]; NumVoxAtDist=[];
                        end %end of loop over columns for optimal memory usage

                        NumDistObjCols=[]; MemLoopIters=[]; MemLoopCols=[];
                    end %end of 'if empty VxlIdxs' check
                end %end of 'if empty rows' check
                
                rows=[]; cols=[]; VxlIdxs=[]; DistanceObjectNOW=[]; DistObjTemp=[];
            end %end of parallel computation loop over slices
            
            ALL_DistObj{c,1}=DistObj; %DistObj (i.e., the number of voxels of the current object at the given distances (given by the rows) from all the RDF origins analyzed for the current cluster
            ALL_DistObj{c,2}=length(COLtemp); %NumConnCompVxls (i.e., the number of individual RDF origins, that will be combined to form the TPCF)
            
            
            %NOTE: do NOT update Fail Site info since no Fail Site DV for
            %control specimens... leave 0's in these fields as initialized
            %above stain cluster loop
%             if (c==FailSiteConnComp)
%                 FailSite_DistObj{1,1}=DistObj; %DistObj (i.e., the number of voxels of the current object at the given distances (given by the rows) from all the RDF origins analyzed for the current cluster
%                 FailSite_DistObj{1,2}=length(COLtemp); %NumConnCompVxls (i.e., the number of individual RDF origins, that will be combined to form the TPCF)
%                 FailSite_DistObj{1,3}=c; %the Fail Site Conn Comp
%             end
            
            clear('COLtemp','ROWtemp','SLICEtemp','DistObj')
        end %end of loop over stain clusters
        matlabpool close
        
            
        % call sub-function "Save_Data"
        Save_Data(SpecimenNum,Object,o,PcentEvalNum,Directory,ALL_DistObj,FailSite_DistObj);
        
        
        clear('Object','ALL_DistObj','FailSite_DistObj');
        
        Duration=toc(ObjTime);
        DurationMin=floor(Duration/60);
        DurationSec=round(((Duration/60)-DurationMin)*60);
        fprintf('\n\t ... Object Complete!  Duration = %d min %d sec\n',DurationMin,DurationSec)
        clear('ObjTime','Duration','DurationMin','DurationSec');
%     end %end of object loop
    
    clear('SpecimenNum','Directory','LoadStainStart','SliceVoxelsMAX');
% end %end of specimen loop

fprintf('\n\nProgram Execution Finished Successfully\n')
TotalTime=toc(StartTime);
TotalTimeMin=floor(TotalTime/60);
TotalTimeSec=round(((TotalTime/60)-TotalTimeMin)*60);
fprintf('Total time elapsed = %d min %d sec\n',TotalTimeMin,TotalTimeSec)
end %end of main function




% Sub-function "LoadLinearIndRUNL"
%
function [OutputDataMatrix]=LoadLinearIndRUNL(Input_LinearIndRUNL,Dim_XYZ,SpecimenNum,ObjectNow)
    LinearInd_ALL=load(Input_LinearIndRUNL,'-mat');
    
    SliceVoxelsMAX=Dim_XYZ(1)*Dim_XYZ(2);%Xdim*Ydim;
    
    %"GaussSupportOffset" is used to account for slices with no voxels at
    %the first and last few slice(s) of each Object based on the Gauss
    %support value used for filtering on the CT system analysis
    if (isempty(regexpi(ObjectNow,'stain')) == 0)
        GaussSupportOffset=3;
        %the string "ObjectNow" contained the string 'stain' which means
        %a Gauss support of 3 was performed on the CT
    else
        GaussSupportOffset=1;
        %the string "ObjectNow" did not contain the string 'stain' which
        %means a Gauss support of 1 was performed on the CT
    end
    
    OutputDataMatrix=zeros([Dim_XYZ(2) Dim_XYZ(1) Dim_XYZ(3)],'int8');%[Ydim Xdim Zdim] %CT-space dimensions
    for slice=(1+GaussSupportOffset):1:(Dim_XYZ(3)-GaussSupportOffset)
        CurrentSlice=strcat('LinearIndexRUNL_',SpecimenNum,'_',ObjectNow,'_Slice',num2str(slice));
        SliceData=LinearInd_ALL.(CurrentSlice);
        LinearInd_ALL=rmfield(LinearInd_ALL,CurrentSlice);%this clears the single, LinearIndexRUNL file that was just assigned to the "SliceData" variable in the previous line of code
        
        LinearInd=zeros(SliceVoxelsMAX,1,'int8');
        if (isempty(SliceData) == 0) %"SliceData" must be non-empty to enter this loop
            for Row=1:1:length(SliceData(:,1))
                %{
                    For the statement below:
                        SliceData(Row,1) = linear index of starting voxel location
                        SliceData(Row,2) = number of extra voxels from the
                                            starting voxel location
                %}
                LinearInd(SliceData(Row,1):1:(SliceData(Row,1)+SliceData(Row,2)),1)=1;
            end
            
            OutputDataMatrix(:,:,slice)=transpose(reshape(LinearInd,Dim_XYZ(1),Dim_XYZ(2)));
            %NOTE: the reshape command is correct as written to say Xdim,Ydim
            %since CT reads row-wise and Matlab orders column-wise, so the
            %shape is just trasposed, but then the "transpose()" command
            %corrects the data to be in the CT coordinate configuration for
            %use with the VoxInterestList values
        end
        
        clear('CurrentSlice','SliceData')
    end
    
    clear('LinearInd_ALL')
end %end of sub-function "LoadLinearIndRUNL"




% Sub-function "RowCol_FromLinearIndRUNL"
%
function [RowCol,RowCol_LOWslice,RowCol_HIGHslice]=RowCol_FromLinearIndRUNL(Input_LinearIndRUNL,Dim_XYZ,SpecimenNum,ObjectNow)
    LinearInd_ALL=load(Input_LinearIndRUNL,'-mat');
    
    SliceVoxelsMAX=Dim_XYZ(1)*Dim_XYZ(2);%Xdim*Ydim;
    
    %"GaussSupportOffset" is used to account for slices with no voxels at
    %the first and last few slice(s) of each Object based on the Gauss
    %support value used for filtering on the CT system analysis
    if (isempty(regexpi(ObjectNow,'stain')) == 0)
        GaussSupportOffset=3;
        %the string "ObjectNow" contained the string 'stain' which means
        %a Gauss support of 3 was performed on the CT
    else
        GaussSupportOffset=1;
        %the string "ObjectNow" did not contain the string 'stain' which
        %means a Gauss support of 1 was performed on the CT
    end
    RowCol_LOWslice=(1+GaussSupportOffset);
    RowCol_HIGHslice=(Dim_XYZ(3)-GaussSupportOffset);
    
    RowCol=struct([]);
    for slice=RowCol_LOWslice:1:RowCol_HIGHslice
        Current_Object=zeros([Dim_XYZ(2) Dim_XYZ(1)],'int8');%[Ydim Xdim] [RowDim ColDim]
        CurrentSlice=strcat('LinearIndexRUNL_',SpecimenNum,'_',ObjectNow,'_Slice',num2str(slice));
        SliceData=LinearInd_ALL.(CurrentSlice);
        LinearInd_ALL=rmfield(LinearInd_ALL,CurrentSlice);%this clears the single, LinearIndexRUNL file that was just assigned to the "SliceData" variable in the previous line of code
        
        LinearInd=zeros(SliceVoxelsMAX,1,'int8');
        if (isempty(SliceData) == 0) %"SliceData" must be non-empty to enter this loop
            for Row=1:1:length(SliceData(:,1))
                %{
                    For the statement below:
                        SliceData(Row,1) = linear index of starting voxel location
                        SliceData(Row,2) = number of extra voxels from the
                                            starting voxel location
                %}
                LinearInd(SliceData(Row,1):1:(SliceData(Row,1)+SliceData(Row,2)),1)=1;
            end
        end
        
        Current_Object=transpose(reshape(LinearInd,Dim_XYZ(1),Dim_XYZ(2)));
        %NOTE: the reshape command is correct as written to say Xdim,Ydim
        %since CT reads row-wise and Matlab orders column-wise, so the
        %shape is just trasposed, but then the "transpose()" command
        %corrects the data to be in the CT coordinate configuration

        [RowNums,ColNums]=find(Current_Object);%locate the rows and columns of non-zero voxels in current object slice

        RowCol(slice,1).Rows=int16(RowNums);%structure variable w/ field "Rows"
        RowCol(slice,1).Cols=int16(ColNums);%structure variable w/ field "Cols"

        clear('CurrentSlice','SliceData','RowNums','ColNums');
    end
    
    clear('LinearInd_ALL')
end %end of sub-function "RowCol_FromLinearIndRUNL"




% Sub-function "RowCol_FromMatrix"
%
function [RowCol,RowCol_LOWslice,RowCol_HIGHslice]=RowCol_FromMatrix(Input_Matrix,Dim_XYZ,ObjectNow)
    %"GaussSupportOffset" is used to account for slices with no voxels at
    %the first and last few slice(s) of each Object based on the Gauss
    %support value used for filtering on the CT system analysis
    if (isempty(regexpi(ObjectNow,'stain')) == 0)
        GaussSupportOffset=3;
        %the string "ObjectNow" contained the string 'stain' which means
        %a Gauss support of 3 was performed on the CT
    else
        GaussSupportOffset=1;
        %the string "ObjectNow" did not contain the string 'stain' which
        %means a Gauss support of 1 was performed on the CT
    end
    RowCol_LOWslice=(1+GaussSupportOffset);
    RowCol_HIGHslice=(Dim_XYZ(3)-GaussSupportOffset);
    
    RowCol=struct([]);
    for slice=RowCol_LOWslice:1:RowCol_HIGHslice
        
        [RowNums,ColNums]=find(Input_Matrix(:,:,slice));%locate the rows and columns of non-zero voxels in current object slice
        
        RowCol(slice,1).Rows=int16(RowNums);%structure variable w/ field "Rows"
        RowCol(slice,1).Cols=int16(ColNums);%structure variable w/ field "Cols"
        
        clear('RowNums','ColNums');
    end
    
end %end of sub-function "RowCol_FromMatrix"




% Sub-function "Save_Data"
%
function Save_Data(SpecimenNum,Object,o,PcentEvalNum,Directory,ALL_DistObj,FailSite_DistObj)
    if (o==1)
        file1a=strcat('DistAvailBinned_GOBJvoxels_',SpecimenNum,'_ALLConnComp_',num2str(PcentEvalNum),'pDV');
        SaveObject1a=matfile(strcat(Directory,file1a),'Writable',true);
        file1aFull=strcat('SaveObject1a.',file1a);
        eval([file1aFull ' = ALL_DistObj;']);

        eval(['clear ' file1a])%this clears the variable "DistAvailBinned_..._ALLConnComp"
        eval(['clear ' file1aFull])%this clears the variable "SaveObject1a..."
        clear('file1a','file1aFull','SaveObject1a');

        file1b=strcat('DistAvailBinned_GOBJvoxels_',SpecimenNum,'_FailSiteConnComp_',num2str(PcentEvalNum),'pDV');
        SaveObject1b=matfile(strcat(Directory,file1b),'Writable',true);
        file1bFull=strcat('SaveObject1b.',file1b);
        eval([file1bFull ' = FailSite_DistObj;']);

        eval(['clear ' file1b])%this clears the variable "DistAvailBinned_..._FailSiteConnComp"
        eval(['clear ' file1bFull])%this clears the variable "SaveObject1b..."
        clear('file1b','file1bFull','SaveObject1b');

    elseif (o==5)
        file1a=strcat('DistAvailBinned_',Object,'_',SpecimenNum,'_ALLConnComp_',num2str(PcentEvalNum),'pDV');
        SaveObject1a=matfile(strcat(Directory,file1a),'Writable',true);
        file1aFull=strcat('SaveObject1a.',file1a);
        eval([file1aFull ' = ALL_DistObj;']);

        eval(['clear ' file1a])%this clears the variable "DistAvailBinned_..._ALLConnComp"
        eval(['clear ' file1aFull])%this clears the variable "SaveObject1a..."
        clear('file1a','file1aFull','SaveObject1a');

        file1b=strcat('DistAvailBinned_',Object,'_',SpecimenNum,'_FailSiteConnComp_',num2str(PcentEvalNum),'pDV');
        SaveObject1b=matfile(strcat(Directory,file1b),'Writable',true);
        file1bFull=strcat('SaveObject1b.',file1b);
        eval([file1bFull ' = FailSite_DistObj;']);

        eval(['clear ' file1b])%this clears the variable "DistAvailBinned_..._FailSiteConnComp"
        eval(['clear ' file1bFull])%this clears the variable "SaveObject1b..."
        clear('file1b','file1bFull','SaveObject1b');

    else
        file2a=strcat('DistObjBinned_',SpecimenNum,'_',Object,'_ALLConnComp_',num2str(PcentEvalNum),'pDV');
        SaveObject2a=matfile(strcat(Directory,file2a),'Writable',true);
        file2aFull=strcat('SaveObject2a.',file2a);
        eval([file2aFull ' = ALL_DistObj;']);

        eval(['clear ' file2a])%this clears the variable "DistAvailBinned_..._ALLConnComp"
        eval(['clear ' file2aFull])%this clears the variable "SaveObject1a..."
        clear('file2a','file2aFull','SaveObject2a');

        file2b=strcat('DistObjBinned_',SpecimenNum,'_',Object,'_FailSiteConnComp_',num2str(PcentEvalNum),'pDV');
        SaveObject2b=matfile(strcat(Directory,file2b),'Writable',true);
        file2bFull=strcat('SaveObject2b.',file2b);
        eval([file2bFull ' = FailSite_DistObj;']);

        eval(['clear ' file2b])%this clears the variable "DistAvailBinned_..._FailSiteConnComp"
        eval(['clear ' file2bFull])%this clears the variable "SaveObject1b..."
        clear('file2b','file2bFull','SaveObject2b');

    end
    
end %end of sub-function "Save_Data"


