function Step4_VoxelCounter3D

%----- Input the desired specimens
WhichGroups={'Ctrl';'Comp';'Tens'}; %Options: "'Ctrl'", "'Comp'", or "'Tens'"
% note: the order here will determine the output variables order below

% Call "Step0_UserInputData" m-file to retrieve user-supplied data
[SpecimenList,VoxInterestList]=Step0_UserInputData(WhichGroups);

ObjInterestList={'STAIN_Peel10'};%'GOBJ' 'PORES' 'lowMNRL' 'highMNRL' 'STAIN_Peel10'};
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

StartTime=tic;
for s=1:length(SpecimenList)
    SpecimenNum=SpecimenList{s};
    Directory=strcat(SpecimenNum,'/');
    fprintf('\nSpecimen Number = %s\n',SpecimenList{s})
    
    PosAndDimsXYZ=open(strcat(Directory,'Images/',SpecimenNum,'_AIM_PositionAndDimension.mat'));
    Dim_XYZ=cell2mat(PosAndDimsXYZ.AIM_PositionAndDimension(2,1:3));
    clear('PosAndDimsXYZ');
    
    for o=1:length(ObjInterestList)
        ObjTime=tic;
        
        Object=ObjInterestList{o};
        
        fprintf('\t\tObject = %s ...',Object)
        
        ImgDir=strcat(Directory,'Images/');
        
        LinearIndRUNL_file=strcat(ImgDir,SpecimenNum,'_',Object,'_LinearIndexRUNL.mat');
        
        %Call sub-function "VoxelCounter3D" to compute and save this
        %segmented object's total voxel count
        VoxelCounter3D(LinearIndRUNL_file,Dim_XYZ,Directory,SpecimenNum,Object);
        
        clear('Object','ImgDir','LinearIndRUNL_file');
        
        Duration=toc(ObjTime);
        DurationMin=floor(Duration/60);
        DurationSec=round(((Duration/60)-DurationMin)*60);
        fprintf(' Complete!  Duration = %d min %d sec\n',DurationMin,DurationSec)
        clear('ObjTime','Duration','DurationMin','DurationSec');
    end
    
    clear('SpecimenNum','Directory','Dim_XYZ')
end
fprintf('\n\nProgram Execution Finished Successfully\n')
TotalTime=toc(StartTime);
TotalTimeMin=floor(TotalTime/60);
TotalTimeSec=round(((TotalTime/60)-TotalTimeMin)*60);
fprintf('Total time elapsed = %d min %d sec\n',TotalTimeMin,TotalTimeSec)
end %end of main function




% Sub-function "VoxelCounter3D"
%
function VoxelCounter3D(Input_LinearIndRUNL,Dim_XYZ,Directory,SpecimenNum,Object)
    LinearInd_ALL=load(Input_LinearIndRUNL,'-mat');
    
    %"GaussSupportOffset" is used to account for slices with no voxels at
    %the first and last few slice(s) of each Object based on the Gauss
    %support value used for filtering on the CT system analysis
    if (isempty(regexpi(Object,'stain')) == 0)
        GaussSupportOffset=3;
        %the string "ObjectNow" contained the string 'stain' which means
        %a Gauss support of 3 was performed on the CT
    else
        GaussSupportOffset=1;
        %the string "ObjectNow" did not contain the string 'stain' which
        %means a Gauss support of 1 was performed on the CT
    end
    
    ObjectTotalVoxCount=0;%initialize
    for slice=(1+GaussSupportOffset):1:(Dim_XYZ(3)-GaussSupportOffset)
        CurrentSlice=strcat('LinearIndexRUNL_',SpecimenNum,'_',Object,'_Slice',num2str(slice));
        SliceData=LinearInd_ALL.(CurrentSlice);
        LinearInd_ALL=rmfield(LinearInd_ALL,CurrentSlice);%this clears the single, LinearIndexRUNL file that was just assigned to the "SliceData" variable in the previous line of code
        
        if (isempty(SliceData) == 0) %"SliceData" must be non-empty to enter this loop
            SliceTotalObjectVoxCount=0;%reset count each time through loop
            
            %{
                For the statement below:
                    SliceData(Row,1) = linear index of starting voxel location
                    SliceData(Row,2) = number of extra voxels from the
                                        starting voxel location
            %}

            SliceTotalObjectVoxCount=length(SliceData(:,1))+sum(SliceData(:,2));

            ObjectTotalVoxCount=ObjectTotalVoxCount+SliceTotalObjectVoxCount;
        end
        
        clear('CurrentSlice','SliceData')
    end
    clear('LinearInd_ALL','SliceTotalObjectVoxCount')


    %save TotalObjectVoxCount
    file1=strcat('ObjectVoxelCountTotal_',SpecimenNum,'_',Object);
    eval([file1 ' = ObjectTotalVoxCount;'])
    save(strcat(Directory,file1),file1);
        
end %end of sub-function "LoadLinearIndRUNL"



