function Step5_PDF_CalcAndPlot_RegularBins

%----- Input the desired specimens
WhichGroups={'Ctrl';'Comp';'Tens'}; %Options: "'Ctrl'", "'Comp'", or "'Tens'"
% note: will call "Step0_UserInputData" below with these groups
% individually for this "Step5_PDF_CalcAndPlot_RegularBins" function m-file

ObjInterestList={'PORES' 'lowMNRL' 'highMNRL' 'STAIN_EaClustRemvd'};

NumSlicesEval=300;%get this number from Step3_TPCF_#pcentStain m-file

VersionNumNOW='5pDV';%used for loading "DistAvail..." and "DistObj..." TPCF data files
SpecificVersionNOWpre=strcat(VersionNumNOW,'RegBins');%used for saving files with altered version nums based on the data handling/plotting below
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
fprintf('\n\nConfirm appropriate version number in user-input section above, see variables "VersionNumNOW" and "SpecificVersionNOWpre"!!!\n')

%set line style order to provide 32 different traces per plot (8 default colors * 4 line styles)
set(0,'DefaultAxesLineStyleOrder','-|--|:|-.')

StartTime=tic;
for GROUPnow=1:length(WhichGroups)
    
    fprintf('\n\nEvaluating Group... %s\n',WhichGroups{GROUPnow})

    % Call "Step0_UserInputData" m-file to retrieve user-supplied data
    [SpecimenList,~]=Step0_UserInputData(WhichGroups(GROUPnow));%2nd output, "VoxInterestList" is unused, so replaced by "~"

    %Sort "SpecimenList" for easy JMP import
    SpecimenList=sort(SpecimenList);

    SpecificVersionNOW=strcat(SpecificVersionNOWpre,WhichGroups{GROUPnow});%update "SpecificVersionNOW" to include the appended study group for this loop
    
    %compute the max distance from all specimens
    MAXdistSpecimen=zeros(length(SpecimenList),1);
    for LoopSpecimen=1:length(SpecimenList)
        SpecimenNum=SpecimenList{LoopSpecimen};
        Directory=strcat(SpecimenNum,'/');

        PosAndDimsXYZ=open(strcat(Directory,'Images/',SpecimenNum,'_AIM_PositionAndDimension.mat'));
        Dim_XYZ=cell2mat(PosAndDimsXYZ.AIM_PositionAndDimension(2,1:3));
        clear('PosAndDimsXYZ');

        MAXdistSpecimen(LoopSpecimen,1)=ceil(sqrt(sum(Dim_XYZ(:).^2)));
    end
    MAXdist=max(MAXdistSpecimen);%used to initialize the size of the "PDF_{X,Y}vals" matrices (below)

    %initialize variables
    CrackDistDnorm=zeros(length(SpecimenList),length(ObjInterestList),2);%2 for number of "vox of interest", but in this case it's FailSite and AllDamage voxels as the second
    CrackDistPDF=zeros(length(SpecimenList),length(ObjInterestList),2);
    PDF_Xvals=zeros(MAXdist,length(SpecimenList),length(ObjInterestList),2);
    PDF_Yvals=zeros(MAXdist,length(SpecimenList),length(ObjInterestList),2);
    clear('MAXdistSpecimen','MAXdist');

    for o=1:length(ObjInterestList)

        Object=ObjInterestList{o};
        
        ObjectLoad=Object;

        if (strcmpi(ObjInterestList{o},'STAIN_EaClustRemvd')==1) %catch STAIN_EaClustRemvd object case
            fprintf('\n\tObject = GOBJ_EaClustRemvdDV and %s\n',Object)
        else
            fprintf('\n\tObject = GOBJ and %s\n',Object)
        end

        LoopCount=0;
        for s=1:length(SpecimenList)
            ObjTime=tic;

            LoopCount=LoopCount+1;
            SpecimenNum=SpecimenList{s};
            Directory=strcat(SpecimenNum,'/');
            fprintf('\t\tSpecimen Number = %s ...',SpecimenList{s})

            %load the object TPCF distance and counts data (actual occurences
            %at each distance)
            file1a=strcat('DistObjBinned_',SpecimenNum,'_',ObjectLoad,'_ALLConnComp_',VersionNumNOW);
            file1b=strcat('DistObjBinned_',SpecimenNum,'_',ObjectLoad,'_FailSiteConnComp_',VersionNumNOW);
            load(strcat(Directory,file1a,'.mat'))
            load(strcat(Directory,file1b,'.mat'))
            eval(['DistObjBinned_ALL = ' file1a ';']);
            eval(['DistObjBinned_FailSiteStruct = ' file1b ';']);
            clearvars DistObjBinned* -except DistObjBinned_ALL DistObjBinned_FailSiteStruct

            %load the gobj TPCF distance and counts data (max possible
            %occurences at each distance)
            if (strcmpi(ObjInterestList{o},'STAIN_EaClustRemvd')==1) %catch STAIN_EaClustRemvd object case
                file2a=strcat('DistAvailBinned_GOBJ_EaClustRemvdDV_',SpecimenNum,'_ALLConnComp_',VersionNumNOW);
                file2b=strcat('DistAvailBinned_GOBJ_EaClustRemvdDV_',SpecimenNum,'_FailSiteConnComp_',VersionNumNOW);
            else
                file2a=strcat('DistAvailBinned_GOBJvoxels_',SpecimenNum,'_ALLConnComp_',VersionNumNOW);
                file2b=strcat('DistAvailBinned_GOBJvoxels_',SpecimenNum,'_FailSiteConnComp_',VersionNumNOW);
            end
            load(strcat(Directory,file2a,'.mat'))
            load(strcat(Directory,file2b,'.mat'))
            eval(['DistAvailBinned_GOBJvoxels_ALL = ' file2a ';']);
            eval(['DistAvailBinned_GOBJvoxels_FailSiteStruct = ' file2b ';']);
            clearvars DistAvailBinned* -except DistAvailBinned_GOBJvoxels_ALL DistAvailBinned_GOBJvoxels_FailSiteStruct

            %sum together the contributions of each cluster into the ALL damage
            %TPCF data (as imported, the data is still on a per stain cluster
            %basis)
            NumConnComp=length(DistAvailBinned_GOBJvoxels_ALL(:,1));%This calculates the number of connected components for the current specimen
            DistObjBinned_ALLsummed=zeros(length(DistObjBinned_ALL{1,1}),1);%initialize DistObjBinned_ALLsummed
            DistAvailBinned_GOBJvoxels_ALLsummed=zeros(length(DistAvailBinned_GOBJvoxels_ALL{1,1}),1);%initialize Avail_ALLsummed
            for ConnCompNow=1:NumConnComp %1:NumConnComp INCLUDES the FailSiteConnComp... could code differently to exclude...
                DistObjBinned_ALLsummed = DistObjBinned_ALLsummed + DistObjBinned_ALL{ConnCompNow,1};
                DistAvailBinned_GOBJvoxels_ALLsummed = DistAvailBinned_GOBJvoxels_ALLsummed + DistAvailBinned_GOBJvoxels_ALL{ConnCompNow,1};
            end
            clear('NumConnComp','DistObjBinned_ALL','DistAvailBinned_GOBJvoxels_ALL');


            DistObjBinned_FailSite=DistObjBinned_FailSiteStruct{1,1};%distance and counts data
            NumConnCompVxls_FailSite=DistObjBinned_FailSiteStruct{1,2};%the number of individual RDF origins, from which the results were combined to form the TPCF

            DistAvailBinned_GOBJvoxels_FailSite=DistAvailBinned_GOBJvoxels_FailSiteStruct{1,1};%distance and counts data
            NumConnCompVxls_GOBJvoxels_FailSite=DistAvailBinned_GOBJvoxels_FailSiteStruct{1,2};%the number of individual RDF origins, from which the results were combined to form the TPCF

            if (NumConnCompVxls_FailSite ~= NumConnCompVxls_GOBJvoxels_FailSite)
                error('Number of ConnComp voxels should be the same for Object and GOBJ!');
            end

            clear('DistObjBinned_FailSiteStruct','DistAvailBinned_GOBJvoxels_FailSiteStruct');


            %the most basic, purely local distance normalization... what was there over what could have been there
            DistanceNorm1=DistObjBinned_FailSite./DistAvailBinned_GOBJvoxels_FailSite;%for FailSite
            DistanceNorm2=DistObjBinned_ALLsummed./DistAvailBinned_GOBJvoxels_ALLsummed;%for ALLdamage

            [RowsDnorm1]=find(~(isnan(DistanceNorm1)));%this omits NaN's
            [RowsDnorm2]=find(~(isnan(DistanceNorm2)));%this omits NaN's

            ValDistNormNoNAN1=DistanceNorm1(RowsDnorm1);%collect the non-NaN's
            ValDistNormNoNAN2=DistanceNorm2(RowsDnorm2);%collect the non-NaN's


            %FIGURE 1A: Most basic distance normalization figure (Dnorm) (FailSite)
            FIGoneA=figure(1);
            if (LoopCount==1); FIGoneAxes1=axes(); end
            Xvalues1=(RowsDnorm1./100);%divide RowsDnorm by 100 to convert from voxels (10 um side) to mm
            plot(FIGoneAxes1,Xvalues1,ValDistNormNoNAN1);
            hold(FIGoneAxes1,'all')
            ylim(FIGoneAxes1,[0 1])%0 and 1 are the absolute lower and upper bound, respectfully... either there's nothing of what could have been or there's everything...
            xlim(FIGoneAxes1,[0 (NumSlicesEval/100)])
            box off

            %FIGURE 1B: Most basic distance normalization figure (Dnorm) (ALLsummed)
            FIGoneB=figure(2);
            if (LoopCount==1); FIGoneAxes2=axes(); end
            Xvalues2=(RowsDnorm2./100);%divide RowsDnorm by 100 to convert from voxels (10 um side) to mm
            plot(FIGoneAxes2,Xvalues2,ValDistNormNoNAN2);
            hold(FIGoneAxes2,'all')
            ylim(FIGoneAxes2,[0 1])%0 and 1 are the absolute lower and upper bound, respectfully... either there's nothing of what could have been or there's everything...
            xlim(FIGoneAxes2,[0 (NumSlicesEval/100)])
            box off


            %Read in voxel count data for volume fraction normalizations
            file3a=strcat('ObjectVoxelCountTotal_',SpecimenNum,'_GOBJ');
            if (strcmpi(ObjInterestList{o},'STAIN_EaClustRemvd')==1) %catch STAIN_EaClustRemvd object case
                file3b=strcat('ObjectVoxelCountTotal_',SpecimenNum,'_','STAIN_Peel10'); %switch back to regular STAIN for this volume fraction calculation...
            else
                file3b=strcat('ObjectVoxelCountTotal_',SpecimenNum,'_',ObjectLoad);
            end
            load(strcat(Directory,file3a,'.mat'))
            load(strcat(Directory,file3b,'.mat'))
            eval(['TotalNumAvailVoxels = ' file3a ';']); %the total number of GOBJ voxels in the gauge section
            eval(['TotalNumObjVoxels = ' file3b ';']); %the total number of object voxels in the gauge section
            clearvars ObjectVoxelCountTotal*

            %FIGURE 2A: Distance normalization further normalized by volume fraction
            %of object of interest (PDF) (FailSite)
            FIGtwoA=figure(3);
            Yvalues1=(ValDistNormNoNAN1.*(TotalNumAvailVoxels/TotalNumObjVoxels));%this is the full PDF value (Dnorm further normalized by the volume fraction of the feature of interest)
            if (LoopCount==1); FIGtwoAxes1=axes(); end
            plot(FIGtwoAxes1,Xvalues1,Yvalues1);%Xvalues were already converted from voxels to mm (above)
            hold(FIGtwoAxes1,'all')
            ylim(FIGtwoAxes1,[0 3])%may need to adjust the upper y range... lower can't be less than 0
            xlim(FIGtwoAxes1,[0 (NumSlicesEval/100)])
            box off

            %FIGURE 2B: Distance normalization further normalized by volume fraction
            %of object of interest (PDF) (ALLsummed)
            FIGtwoB=figure(4);
            Yvalues2=(ValDistNormNoNAN2.*(TotalNumAvailVoxels/TotalNumObjVoxels));%this is the full PDF value (Dnorm further normalized by the volume fraction of the feature of interest)
            if (LoopCount==1); FIGtwoAxes2=axes(); end
            plot(FIGtwoAxes2,Xvalues2,Yvalues2);%Xvalues were already converted from voxels to mm (above)
            hold(FIGtwoAxes2,'all')
            ylim(FIGtwoAxes2,[0 3])%may need to adjust the upper y range... lower can't be less than 0
            xlim(FIGtwoAxes2,[0 (NumSlicesEval/100)])
            box off

            %save all plot values
            PDF_Xvals(1:length(Xvalues1),s,o,1)=Xvalues1;%FailSite
            PDF_Xvals(1:length(Xvalues2),s,o,2)=Xvalues2;%ALLdamage

            PDF_Yvals(1:length(Yvalues1),s,o,1)=Yvalues1;%FailSite
            PDF_Yvals(1:length(Yvalues2),s,o,2)=Yvalues2;%ALLdamage


            CrackDist=[44];%this the number of VOXELS distance at which length a crack becomes unstable (Mohsin2006/O'Brien2005) (10 um voxel, therefore 44 voxels = 440 �m)

            for cd=1:length(CrackDist)
                CrackDistObj1=sum(DistObjBinned_FailSite(1:CrackDist(cd)));%FailSite
                CrackDistObj2=sum(DistObjBinned_ALLsummed(1:CrackDist(cd)));%ALLdamage

                CrackDistAvail1=sum(DistAvailBinned_GOBJvoxels_FailSite(1:CrackDist(cd)));%FailSite
                CrackDistAvail2=sum(DistAvailBinned_GOBJvoxels_ALLsummed(1:CrackDist(cd)));%ALLdamage

                CrackDistDnorm(s,o,1,cd)=CrackDistObj1/CrackDistAvail1;%FailSite
                CrackDistDnorm(s,o,2,cd)=CrackDistObj2/CrackDistAvail2;%ALLdamage

                CrackDistPDF(s,o,1,cd)=CrackDistDnorm(s,o,1,cd)*(TotalNumAvailVoxels/TotalNumObjVoxels);%FailSite
                CrackDistPDF(s,o,2,cd)=CrackDistDnorm(s,o,2,cd)*(TotalNumAvailVoxels/TotalNumObjVoxels);%ALLdamage
            end

            clear('SpecimenNum','Directory',...
                'file1a','file1b','file2a','file2b',...
                'DistObjBinned_ALLsummed','DistAvailBinned_GOBJvoxels_ALLsummed',...
                'DistObjBinned_FailSite','DistAvailBinned_GOBJvoxels_FailSite',...
                'DistAvailGOBJvoxels_BigBins2','DistObj_BigBins2',...
                'DistAvailGOBJvoxels_BigBins1','DistObj_BigBins1',...
                'DistanceNormBigBins2','DistanceNormBigBins1',...
                'RowsDnormBigBin2','RowsDnormBigBin1',...
                'ValDistNormNoNANBigBin2','ValDistNormNoNANBigBin1',...
                'Xvalues2','Xvalues1',...
                'TotalNumAvailVoxels','TotalNumObjVoxels','Yvalues2','Yvalues1',...
                'cd')
            clearvars CrackDist* -except CrackDist CrackDistDnorm CrackDistPDF

            Duration=toc(ObjTime);
            DurationMin=floor(Duration/60);
            DurationSec=round(((Duration/60)-DurationMin)*60);
            fprintf(' Complete!  Duration = %d min %d sec\n',DurationMin,DurationSec)
            clear('ObjTime','Duration','DurationMin','DurationSec')
        end

        site1='FailSite';
        site2='AllDamage';

        % Fig1A and 1B:  Dnorm figs for 1A: for FailSite cluster, and 1B: All clusters summed
        FigTitle1A=strcat('3D_DnormTPCF_',site1,'_',Object,'_AllSpecimens',SpecificVersionNOW);
        title(FIGoneAxes1,FigTitle1A,'Interpreter','none')
        legend(FIGoneAxes1,SpecimenList)
        xlabel(FIGoneAxes1,'Radial Distance from Voxel of Interest [mm]')
        ylabel(FIGoneAxes1,'Distance Volume Fraction')
        saveas(FIGoneA,strcat('ALL_Dnorm_Plots/',FigTitle1A),'tif')
        print(FIGoneA,'-depsc',strcat('ALL_Dnorm_Plots/',FigTitle1A,'.eps'))%saves to a color eps file!
        hold(FIGoneAxes1,'off')
        close(FIGoneA)

        FigTitle1B=strcat('3D_DnormTPCF_',site2,'_',Object,'_AllSpecimens',SpecificVersionNOW);
        title(FIGoneAxes2,FigTitle1B,'Interpreter','none')
        legend(FIGoneAxes2,SpecimenList)
        xlabel(FIGoneAxes2,'Radial Distance from Voxel of Interest [mm]')
        ylabel(FIGoneAxes2,'Distance Volume Fraction')
        saveas(FIGoneB,strcat('ALL_Dnorm_Plots/',FigTitle1B),'tif')
        print(FIGoneB,'-depsc',strcat('ALL_Dnorm_Plots/',FigTitle1B,'.eps'))%saves to a color eps file!
        hold(FIGoneAxes2,'off')
        close(FIGoneB)


        % Fig2A and 2B:  PDF figs for 2A: for FailSite cluster, and 2B: All clusters summed
        FigTitle2A=strcat('3D_PDF_',site1,'_',Object,'_AllSpecimens',SpecificVersionNOW);
        title(FIGtwoAxes1,FigTitle2A,'Interpreter','none')
        legend(FIGtwoAxes1,SpecimenList)
        xlabel(FIGtwoAxes1,'Radial Distance from Voxel of Interest [mm]')
        ylabel(FIGtwoAxes1,'PDF (Volume Fraction)/(Total Volume Fraction)')
        saveas(FIGtwoA,strcat('ALL_PDF_Plots/',FigTitle2A),'tif')
        print(FIGtwoA,'-depsc',strcat('ALL_PDF_Plots/',FigTitle2A,'.eps'))%saves to a color eps file!
        hold(FIGtwoAxes1,'off')
        close(FIGtwoA)

        FigTitle2B=strcat('3D_PDF_',site2,'_',Object,'_AllSpecimens',SpecificVersionNOW);
        title(FIGtwoAxes2,FigTitle2B,'Interpreter','none')
        legend(FIGtwoAxes2,SpecimenList)
        xlabel(FIGtwoAxes2,'Radial Distance from Voxel of Interest [mm]')
        ylabel(FIGtwoAxes2,'PDF (Distance Volume Fraction)/(Total Volume Fraction)')
        saveas(FIGtwoB,strcat('ALL_PDF_Plots/',FigTitle2B),'tif')
        print(FIGtwoB,'-depsc',strcat('ALL_PDF_Plots/',FigTitle2B,'.eps'))%saves to a color eps file!
        hold(FIGtwoAxes2,'off')
        close(FIGtwoB)

        clear('FigTitle1B','FigTitle1A','FigTitle2B','FigTitle2A',...
            'FIGoneB','FIGoneA','FIGtwoB','FIGtwoA',...
            'FIGoneAxes2','FIGoneAxes1','FIGtwoAxes2','FIGtwoAxes1')

        clear('Object','LoopCount')
    end


    %This loop clears the extra space from the PDF_{Xvals/YVals} matrices
    LastRowOld=0;
    for cc=[1 2]% 2 for number of "vox of interest", but in this case it's FailSite cluster (=1) and all damage clusters as the second (=2)
                %the "2" replaced the following: length(VoxInterestListRow(1,:))
        for bb=1:length(ObjInterestList)
            for aa=1:length(SpecimenList)
                LastRowNew=find(PDF_Xvals(:,aa,bb,cc),1,'last');
                if (LastRowNew>LastRowOld)
                    LastRowOld=LastRowNew;
                end
            end
        end
    end
    PDF_Xvals(LastRowOld+1:end,:,:,:)=[];
    PDF_Yvals(LastRowOld+1:end,:,:,:)=[];

    %This loop saves the individual object and vox interest matrices from the
    %larger PDF_{Xvals/Yvals} matrix
    for VoxIntNum=[1 2]
        if (VoxIntNum==1)
            SiteNow='FailSite';
        elseif (VoxIntNum==2)
            SiteNow='AllDamage';
        else
            error('VoxIntNum number not recognized!');
        end

        for ObjNum=1:length(ObjInterestList)

            Object=ObjInterestList{ObjNum};

            PDF_file_name_Xvals=strcat('PDF_',Object,'_',SiteNow,'_Xvals',SpecificVersionNOW);
            PDF_file_name_Yvals=strcat('PDF_',Object,'_',SiteNow,'_Yvals',SpecificVersionNOW);

            PDF_Xvals_temp=PDF_Xvals(:,:,ObjNum,VoxIntNum);
            PDF_Yvals_temp=PDF_Yvals(:,:,ObjNum,VoxIntNum);

            eval([PDF_file_name_Xvals ' = PDF_Xvals_temp;'])
            eval([PDF_file_name_Yvals ' = PDF_Yvals_temp;'])

            save(strcat('ALL_PDF_Plots/',PDF_file_name_Xvals),PDF_file_name_Xvals)
            save(strcat('ALL_PDF_Plots/',PDF_file_name_Yvals),PDF_file_name_Yvals)

            clearvars PDF_* -except PDF_Xvals PDF_Yvals
            clear('Object');
        end

        clear('SiteNow','ObjNum');
    end

    %This portion converts the PDF_{Xvals/Yvals} info into a format to be easily imported into JMP
    %initialize cells
    [PDFrows,PDFspecimens,PDFobjs,PDFsites]=size(PDF_Xvals);
    JMPdata_PDF_AllObj=cell((PDFrows*PDFspecimens*PDFobjs),5,PDFsites); %5 columns because column labels will be {'Specimen_X','Xval','Specimen_Y','Yval','Object'}

    %place X and Y PDF data into cell arrays
    for SiteNum=1:PDFsites
        PDF_Xreshaped=zeros(PDFrows*PDFspecimens,PDFobjs);
        PDF_Yreshaped=zeros(PDFrows*PDFspecimens,PDFobjs);
        for ObjNum=1:PDFobjs
            PDF_Xreshaped(:,ObjNum)=reshape(PDF_Xvals(:,:,ObjNum,SiteNum)',PDFrows*PDFspecimens,1);
            PDF_Yreshaped(:,ObjNum)=reshape(PDF_Yvals(:,:,ObjNum,SiteNum)',PDFrows*PDFspecimens,1);
        end
        JMPdata_PDF_AllObj(:,2,SiteNum)=num2cell(vertcat(PDF_Xreshaped(:)));%PDF x-values
        JMPdata_PDF_AllObj(:,4,SiteNum)=num2cell(vertcat(PDF_Yreshaped(:)));%PDF y-values
    end
    clear('SiteNum','ObjNum');

    %eliminate 0-valued cells (i.e., cells that have no corresponding PDF data)
    for SiteNum=1:PDFsites
        for PDFcolNOW=[2 4] %i.e., the PDF Xval and Yval columns
            for PDFrowNOW=1:(PDFrows*PDFspecimens*PDFobjs) %this is all rows of JMPdata_PDF_AllObj
                if (JMPdata_PDF_AllObj{PDFrowNOW,PDFcolNOW,SiteNum}==0); 
                    JMPdata_PDF_AllObj{PDFrowNOW,PDFcolNOW,SiteNum}=[];
                end
            end
        end
    end
    clear('SiteNum');

    %set up and apply specimen labels
    Specimen_Labels=repmat(SpecimenList,PDFrows*PDFobjs,1);
    for SiteNum=1:PDFsites
        JMPdata_PDF_AllObj(:,1,SiteNum)=Specimen_Labels;
        JMPdata_PDF_AllObj(:,3,SiteNum)=Specimen_Labels;
    end
    clear('SiteNum');

    %set up and apply object labels
    Object_Labels_Build=repmat(ObjInterestList,PDFrows*PDFspecimens,1);
    Object_Labels=vertcat(Object_Labels_Build(:));
    clear('ObjNum');

    for SiteNum=1:PDFsites
        JMPdata_PDF_AllObj(:,5,SiteNum)=Object_Labels;
    end
    clear('SiteNum');

    %set up column labels
    JMPdata_PDF_ColumnLabels={'Specimen_X','Xval','Specimen_Y','Yval','Object'};
    JMPdata_PDF_ColumnLabels=repmat(JMPdata_PDF_ColumnLabels,[1 1 PDFsites]);

    %finalize by concatenating column labels to top of cell structures
    JMPdata_PDF_AllObj=vertcat(JMPdata_PDF_ColumnLabels,JMPdata_PDF_AllObj);

    %write the data to an Excel file for easy import into JMP
    for SiteNum=1:PDFsites
        if (SiteNum==1)
                SiteNow='FailSite';
            elseif (SiteNum==2)
                SiteNow='AllDamage';
            else
                error('SiteNum not recognized!');
        end
        
        ExcelFileSaveName=strcat('ALL_PDF_Plots/JMPdata_PDF_',SiteNow,'_',SpecificVersionNOW,'.xlsx');
        
        WriteDataNow=JMPdata_PDF_AllObj(:,:,SiteNum);

        [SuccessStatus,ErrMesg]=xlswrite(ExcelFileSaveName,WriteDataNow);

        if (SuccessStatus==0)
            error('\n\nDid not save Excel file correctly!  See error message below...\n\n%s.',ErrMesg.message)
        end
        
        clear('SiteNow','ExcelFileSaveName','WriteDataNow','SuccessStatus','ErrMesg');
    end
    clear('SiteNum');




    %Save entire matrices of the CrackDist{Dnorm/PDF} values and labels
    % for specimens (rows) and objects (columns) for the CrackDist* matrix
    CrackDistDnorm_LabelsAndData=cell(1,5);
    CrackDistDnorm_LabelsAndData{1,1}=['rows';SpecimenList];
    CrackDistDnorm_LabelsAndData{1,2}=['cols',ObjInterestList];
    CrackDistDnorm_LabelsAndData{1,3}={'3rd dim';'FailSite';'AllDamage'};
    CrackDistDnorm_LabelsAndData{1,4}=['4th dim';num2cell(CrackDist')];
    CrackDistDnorm_LabelsAndData{1,5}=CrackDistDnorm;
    save(strcat('MeanPDF_data/CrackDistDnorm_LabelsAndData',SpecificVersionNOW),'CrackDistDnorm_LabelsAndData')
    
    CrackDistPDF_LabelsAndData=cell(1,5);
    CrackDistPDF_LabelsAndData{1,1}=['rows';SpecimenList];
    CrackDistPDF_LabelsAndData{1,2}=['cols',ObjInterestList];
    CrackDistPDF_LabelsAndData{1,3}={'3rd dim';'FailSite';'AllDamage'};
    CrackDistPDF_LabelsAndData{1,4}=['4th dim';num2cell(CrackDist')];
    CrackDistPDF_LabelsAndData{1,5}=CrackDistPDF;
    save(strcat('MeanPDF_data/CrackDistPDF_LabelsAndData',SpecificVersionNOW),'CrackDistPDF_LabelsAndData')
    %{
                    Key for the above matrices
                        Rows:  SPECIMENS
                        Cols:  OBJECTS OF INTEREST (see "ObjInterestList" variable)
                        3rdDim: SITE (:,:,1,:)=FailSite  (:,:,2,:)=ALLdamage
                        4thDim: Unstable crack distances analyzed (see "CrackDist" variable above!)

                    So matrix (first 2 indices) looks like following for each "CrackDist" entry (then repeat in 3-D for sites and 4-D for crack distances)
                              PORES   lowMNRL ...
                    Specimen1    #       #
                    Specimen2    #       #
                    Specimen3    #       #
                %}



    %Compute the meanPDF and standard deviation
    [~,loop2size,loop3size,loop4size]=size(CrackDistDnorm);%Description of outputs: [Specimens=UNUSED,Objects,VoxInterest,Number of "CrackDistancesAnalyzed]
    CrackDistDnormAVG=zeros(loop3size,loop2size,loop4size);
    CrackDistDnormSTDDEV=zeros(loop3size,loop2size,loop4size);
    CrackDistPDF_AVG=zeros(loop3size,loop2size,loop4size);
    CrackDistPDF_STDDEV=zeros(loop3size,loop2size,loop4size);
    for loop4=1:loop4size
        CrackDistName=strcat('UnstableCrackDist',num2str(CrackDist(loop4)),SpecificVersionNOW);

        for loop3=1:loop3size
            if (loop3==1)
                SiteNow='FailSite';
            elseif (loop3==2)
                SiteNow='AllDamage';
            else
                error('SiteNow number not recognized!');
            end

            for loop2=1:loop2size

                Object=ObjInterestList{loop2};


                CrackDistDnormAVG_temp=mean(CrackDistDnorm(:,loop2,loop3,loop4));
                CrackDistDnormSTDDEV_temp=std(CrackDistDnorm(:,loop2,loop3,loop4));
                CrackDistPDF_AVG_temp=mean(CrackDistPDF(:,loop2,loop3,loop4));
                CrackDistPDF_STDDEV_temp=std(CrackDistPDF(:,loop2,loop3,loop4));

                %can use the next 3 small sections collectively to save individual pieces of
                %the data, or can use the one bottom-most section of code in this loop
                %to save all at once... (or can use both sections of code)
    %             DataNameDnormAVG=strcat('DnormAVG_',Object,'_',SiteNow,'_',CrackDistName);
    %             DataNameDnormSTDDEV=strcat('DnormSTDDEV_',Object,'_',SiteNow,'_',CrackDistName);
    %             DataNamePDF_AVG=strcat('PDF_AVG_',Object,'_',SiteNow,'_',CrackDistName);
    %             DataNamePDF_STDDEV=strcat('PDF_STDDEV_',Object,'_',SiteNow,'_',CrackDistName);

    %             eval([DataNameDnormAVG ' = CrackDistDnormAVG_temp;'])
    %             eval([DataNameDnormSTDDEV ' = CrackDistDnormSTDDEV_temp;'])
    %             eval([DataNamePDF_AVG ' = CrackDistPDF_AVG_temp;'])
    %             eval([DataNamePDF_STDDEV ' = CrackDistPDF_STDDEV_temp;'])

                %use the 4 lines below to save each object/site/crackdist entity as its own file
    %             save(strcat('MeanPDF_data/AVGandSTDDEV_Expanded/',DataNameDnormAVG),DataNameDnormAVG)
    %             save(strcat('MeanPDF_data/AVGandSTDDEV_Expanded/',DataNameDnormSTDDEV),DataNameDnormSTDDEV)
    %             save(strcat('MeanPDF_data/AVGandSTDDEV_Expanded/',DataNamePDF_AVG),DataNamePDF_AVG)
    %             save(strcat('MeanPDF_data/AVGandSTDDEV_Expanded/',DataNamePDF_STDDEV),DataNamePDF_STDDEV)


                %use the 4 lines below to prepare to save all at once in one file
                CrackDistDnormAVG(loop3,loop2,loop4)=CrackDistDnormAVG_temp;
                CrackDistDnormSTDDEV(loop3,loop2,loop4)=CrackDistDnormSTDDEV_temp;
                CrackDistPDF_AVG(loop3,loop2,loop4)=CrackDistPDF_AVG_temp;
                CrackDistPDF_STDDEV(loop3,loop2,loop4)=CrackDistPDF_STDDEV_temp;
                %{
                    Key for the above matrices
                        Rows:  1=FailSite   2=AllDamage
                        Cols:  1=PORES      2=lowMNRL     3=highMNRL
                        3rdDim: Unstable crack distances analyzed (see "CrackDist" variable above!)

                    So matrix looks like following for each "CrackDist" entry
                              PORES   lowMNRL   ...
                    FailSite    #       #        #
                    AllDamage   #       #        #
                %}
            end
        end
    end

    %Save CrackDist{AVG/STDDEV} and PDF_{AVG/STDDEV} values and labels for
    % damage origins (rows) and objects (cols) for the CrackDist* matrix
    CrackDistDnormAVG_LabelsAndData=cell(1,4);
    CrackDistDnormAVG_LabelsAndData{1,1}={'rows';'FailSite';'AllDamage'};
    CrackDistDnormAVG_LabelsAndData{1,2}=['cols',ObjInterestList];
    CrackDistDnormAVG_LabelsAndData{1,3}=['3rd dim';num2cell(CrackDist')];
    CrackDistDnormAVG_LabelsAndData{1,4}=CrackDistDnormAVG;
    save(strcat('MeanPDF_data/CrackDistDnormAVG_LabelsAndData',SpecificVersionNOW),'CrackDistDnormAVG_LabelsAndData')
    
    CrackDistDnormSTDDEV_LabelsAndData=cell(1,4);
    CrackDistDnormSTDDEV_LabelsAndData{1,1}={'rows';'FailSite';'AllDamage'};
    CrackDistDnormSTDDEV_LabelsAndData{1,2}=['cols',ObjInterestList];
    CrackDistDnormSTDDEV_LabelsAndData{1,3}=['3rd dim';num2cell(CrackDist')];
    CrackDistDnormSTDDEV_LabelsAndData{1,4}=CrackDistDnormSTDDEV;
    save(strcat('MeanPDF_data/CrackDistDnormSTDDEV_LabelsAndData',SpecificVersionNOW),'CrackDistDnormSTDDEV_LabelsAndData')
    
    CrackDistPDF_AVG_LabelsAndData=cell(1,4);
    CrackDistPDF_AVG_LabelsAndData{1,1}={'rows';'FailSite';'AllDamage'};
    CrackDistPDF_AVG_LabelsAndData{1,2}=['cols',ObjInterestList];
    CrackDistPDF_AVG_LabelsAndData{1,3}=['3rd dim';num2cell(CrackDist')];
    CrackDistPDF_AVG_LabelsAndData{1,4}=CrackDistPDF_AVG;
    save(strcat('MeanPDF_data/CrackDistPDF_AVG_LabelsAndData',SpecificVersionNOW),'CrackDistPDF_AVG_LabelsAndData')
    
    CrackDistPDF_STDDEV_LabelsAndData=cell(1,4);
    CrackDistPDF_STDDEV_LabelsAndData{1,1}={'rows';'FailSite';'AllDamage'};
    CrackDistPDF_STDDEV_LabelsAndData{1,2}=['cols',ObjInterestList];
    CrackDistPDF_STDDEV_LabelsAndData{1,3}=['3rd dim';num2cell(CrackDist')];
    CrackDistPDF_STDDEV_LabelsAndData{1,4}=CrackDistPDF_STDDEV;
    save(strcat('MeanPDF_data/CrackDistPDF_STDDEV_LabelsAndData',SpecificVersionNOW),'CrackDistPDF_STDDEV_LabelsAndData')
    
    clear('SpecimenList','SpecificVersionNOW');
end

fprintf('\n\nProgram Execution Finished Successfully\n')
TotalTime=toc(StartTime);
TotalTimeMin=floor(TotalTime/60);
TotalTimeSec=round(((TotalTime/60)-TotalTimeMin)*60);
fprintf('Total time elapsed = %d min %d sec\n',TotalTimeMin,TotalTimeSec)
end



