clear all
close all
clc

VersionNumNOW='5pDVRegBinsTens';
fprintf('\n\nConfirm appropriate version number in user-input section above, see variables "VersionNumNOW"!!!\n\n')

Directory='MeanPDF_data/';

Distances=[440];%400:400:6000;%get these numbers from whatever voxels were used in PlotRadialDistributionFxn3D_LargeBins_PLOTHOLD.m approx line 231!!!
%Note that 'Ditances' is in units of m!

file2a=strcat(Directory,strcat('CrackDistPDF_AVG_LabelsAndData',VersionNumNOW,'.mat'));
file2b=strcat(Directory,strcat('CrackDistPDF_STDDEV_LabelsAndData',VersionNumNOW,'.mat'));

%load the AVG and STDDEV LabelsAndData cell structures
load(file2a)
load(file2b)

%extract only the PDF_{AVG/STDDEV} data matrix
CrackDistPDF_AVG=CrackDistPDF_AVG_LabelsAndData{1,4};
CrackDistPDF_STDDEV=CrackDistPDF_STDDEV_LabelsAndData{1,4};

[Locations,Objects,NumDist]=size(CrackDistPDF_AVG);
%Locations = number of sites investigated (e.g., FailSite and AllDamage sites OR failure and non-failure site) 
%Objects = number of objects (e.g., PV and HMV)
%NumDist = number of unstable crack distances analyzed

% Plot data
StartTime=tic;
for m=1:NumDist
    PORESavg=CrackDistPDF_AVG(:,1,m);%multiple rows would be for failure vs. non-failure sites
    PORESstddev=CrackDistPDF_STDDEV(:,1,m);
    
    lowMNRLavg=CrackDistPDF_AVG(:,2,m);
    lowMNRLstddev=CrackDistPDF_STDDEV(:,2,m);
    
    highMNRLavg=CrackDistPDF_AVG(:,3,m);
    highMNRLstddev=CrackDistPDF_STDDEV(:,3,m);
    
    STAIN_EaClustRemvd_avg=CrackDistPDF_AVG(:,4,m);
    STAIN_EaClustRemvd_stddev=CrackDistPDF_STDDEV(:,4,m);
    
    %{
        NOTE: can obtain the object of interest column order of the above
        "CrackDistPDF_AVG" columns from
        "CrackDistPDF_AVG_LabelsAndData{1,2}"
    %}
    
    for k=1:Locations
        Data=[PORESavg(k,1) lowMNRLavg(k,1) highMNRLavg(k,1) STAIN_EaClustRemvd_avg(k,1)];
        Error=[PORESstddev(k,1) lowMNRLstddev(k,1) highMNRLstddev(k,1) STAIN_EaClustRemvd_stddev(k,1)];
        
        BarWidth1=0.5;
        Xlocations=1:1:Objects;%1:BarWidth1*(1/Objects):1+((Objects/2)*(BarWidth1*(1/Objects)));
        XLim1=[0.5 Objects+.5];%[1-(BarWidth1*.33) Xlocations(end)+(BarWidth1*.33)];
        CurrentFig=figure(k);
        set(CurrentFig,'Color','white')
        Axis1 = axes();
        
        % Create line at PDF = 1
        line(XLim1,[1 1],'Color','k','LineStyle','--','LineWidth',2)
        hold on
        
        % Create Bar Plot of Data
        bar(Axis1,Xlocations,Data,'EdgeColor','k','FaceColor','w',...
            'LineWidth',2,'BarWidth',BarWidth1,'XDataMode','auto');
        Yname=strcat('Average PDF (',num2str(Distances(m)),' m)');
        ylabel(Yname,'FontSize',16,'FontWeight','Bold')
        ylim([0 3])%6  OR  max(ceil(Error+Data))
%         set(Axis1,'XLim',XLim1)
        set(Axis1,'XTick',Xlocations,...
            'XTickLabel','PORES|lowMNRL|highMNRL|STAIN_EaClustRemvd',...
            'FontName','Arial','FontSize',12,'LineWidth',2);
        
        % Create Error Bar Plot to overlay on Bar Plot
        errorbar(Axis1,Xlocations,Data,Error,'LineStyle','none',...
            'Color','k','LineWidth',2);
        
        % Add a title to the plot
        if k==1%fracture initiation site (FailSite cluster voxels)
            FigTitleName=strcat('FailSite__meanPDF_at_',num2str(Distances(m)),'m__',VersionNumNOW);
        elseif k==2%AllDamage voxels
            FigTitleName=strcat('AllDamage__meanPDF_at_',num2str(Distances(m)),'m__',VersionNumNOW);
        end
        title(FigTitleName,'Interpreter','none');
        
        box off
        hold off
        
        
        % Save Figure
        if k==1%fracture initiation site (FailSite cluster voxels)
            FigName=strcat(Directory,'Plots/MeanPDF_FailSite_',num2str(Distances(m)),'_',VersionNumNOW);
        elseif k==2%AllDamage voxels
            FigName=strcat(Directory,'Plots/MeanPDF_AllDamage_',num2str(Distances(m)),'_',VersionNumNOW);
        end
        saveas(CurrentFig,FigName,'tif')
        print(CurrentFig,'-depsc',strcat(FigName,'.eps'))%saves to a color eps file!
        
        % Close Figure
        close(CurrentFig)
        
        clear('Data','Error','CurrentFig','Axis1','Yname','FigName')
    end
    
    clearvars PORES* lowMNRL* highMNRL* STAIN*
end

fprintf('\n\nProgram Execution Finished Successfully\n')
TotalTime=toc(StartTime);
TotalTimeMin=floor(TotalTime/60);
TotalTimeSec=round(((TotalTime/60)-TotalTimeMin)*60);
fprintf('Total time elapsed = %d min %d sec\n',TotalTimeMin,TotalTimeSec)