function Step7_VolumeFractions_AllObjects

%----- Input the desired specimens
WhichGroups={'Ctrl';'Comp';'Tens'}; %Options: "'Ctrl'", "'Comp'", "'Tens'"
% note: the order here will determine the output variables order below

% Call "Step0_UserInputData" m-file to retrieve user-supplied data
[SpecimenList,VoxInterestList]=Step0_UserInputData(WhichGroups);

ObjInterestList={'PORES' 'lowMNRL' 'highMNRL' 'STAIN_Peel10'};

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

%Sort "SpecimenList" for easy JMP import
SpecimenList=sort(SpecimenList);

SaveDirectory='VolumeFractions_AllObjects/';

StartTime=tic;
for o=1:length(ObjInterestList)
    Object=ObjInterestList{o};
    fprintf('\n\nObject = %s',Object)
    
    %initialize cell array to hold volume fraction data
    OBJ_VolFract=cell(length(SpecimenList),2);
    
    %insert specimen numbers in first column
    OBJ_VolFract(:,1)=SpecimenList;

    for s=1:length(SpecimenList)
        SpecimenNum=SpecimenList{s};
        Directory=strcat(SpecimenNum,'/');
        fprintf('\n\tSpecimen Number = %s',SpecimenNum)
        
        %load the GOBJ file for the total volume in the gauge section
        file1=strcat('ObjectVoxelCountTotal_',SpecimenNum,'_GOBJ');
        load(strcat(Directory,file1,'.mat'))
        eval(['GOBJvox = ' file1 ';']);
        clearvars ObjectVoxelCountTotal_*
        clear('file1')
        
        if (isempty(regexpi(Object,'pores')) == 0) %catch PORES object case
            %prepare current object file name
            file2=strcat('ObjectVoxelCountTotal_',SpecimenNum,'_',Object);
        else
            %prepare current object file name
            file2=strcat('ObjectVoxelCountTotal_',SpecimenNum,'_',Object);
            
            %for all other objects objects, the PORE volume is also required
            file3=strcat('ObjectVoxelCountTotal_',SpecimenNum,'_PORES');
            load(strcat(Directory,file3,'.mat'))
            eval(['PORESvox = ' file3 ';']);
            clearvars ObjectVoxelCountTotal_*
            clear('file3')
        end
        load(strcat(Directory,file2,'.mat'))
        eval(['OBJvox = ' file2 ';']);
        clearvars ObjectVoxelCountTotal_*
        clear('file2')
        
        %NOTE: the calculation below will account for the (bv+dv) in the
        %denominator since we are pulling the bv in the below calculation from
        %the pre-stain image... i.e., the segmented bone is just bone and
        %doesn't include dv.  Note that bv = gobj - pores!
        if (isempty(regexpi(Object,'pores')) == 0) %catch PORES object case
            OBJ_VolFract{s,2}=OBJvox/GOBJvox; % OBJ/TV (e.g., PV/TV)
        else
            OBJ_VolFract{s,2}=OBJvox/(GOBJvox-PORESvox); % OBJ/BV (e.g., LMV/BV, HMV/BV, DV/BV)
        end
        
        clear('SpecimenNum','Directory')
        clear('OBJvox','PORESvox','GOBJvox')
    end

    if (isempty(regexpi(Object,'stain')) == 0) %catch STAIN* object case
        FileName=strcat('DVoverBV_',Object);
        eval([FileName ' = OBJ_VolFract;'])
        save(strcat(SaveDirectory,FileName),FileName)
        
    elseif (strcmpi(Object,'PORES')==1) %catch PORES object case
        FileName='PVoverTV';
        eval([FileName ' = OBJ_VolFract;'])
        save(strcat(SaveDirectory,FileName),FileName)
        
    elseif (strcmpi(Object,'lowMNRL')==1) %catch lowMNRL object case
        FileName='LMVoverBV';
        eval([FileName ' = OBJ_VolFract;'])
        save(strcat(SaveDirectory,FileName),FileName)
        
    elseif (strcmpi(Object,'highMNRL')==1) %catch highMNRL object case
        FileName='HMVoverBV';
        eval([FileName ' = OBJ_VolFract;'])
        save(strcat(SaveDirectory,FileName),FileName)
    end
    
    clear('Object','OBJ_VolFract','FileName')
end

fprintf('\n\nProgram Execution Finished Successfully\n')
TotalTime=toc(StartTime);
TotalTimeMin=floor(TotalTime/60);
TotalTimeSec=round(((TotalTime/60)-TotalTimeMin)*60);
fprintf('Total time elapsed = %d min %d sec\n',TotalTimeMin,TotalTimeSec)




