function Step8_TPCF_PeakAndLocation

%----- Input the desired specimens
WhichGroups={'Ctrl';'Comp';'Tens'}; %Options: "'Ctrl'", "'Comp'", "'Tens'"
% note: the order here will determine the output variables order below

ObjInterestList={'PORES' 'lowMNRL' 'highMNRL' 'STAIN_EaClustRemvd'};

%These version variables will be used in the sections below in conjunction
%with the specific group and object loops to call the correct files.
VersionNumNOW='5p';%enter only the percent of cluster voxels analyzed here, e.g., "5p", or "50p"
BinType='RegBins';%enter 'RegBins' or 'BigBins' depending on how PDF data was saved in Step5
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
fprintf('\n\nConfirm appropriate version number in user-input section above, see variables "VersionNumNOW" and "BinType"!!!\n')

DistToSearch=440; %max distance range in microns to search for peak PDF values
DistToSearch=DistToSearch/1000; %convert to millimeters (units of the data files below)

%Specify load and save directory paths
LoadDirectory='ALL_PDF_Plots/';
SaveDirectory=strcat(LoadDirectory,'PDF_Peaks_data/');

StartTime=tic;
for GROUPnow=1:length(WhichGroups)
    
    Trigger_Save=0; % 0 until "Peak_XYvals_ALLdata_JMP" is created, then turns to 1 and additional data is appended to "Peak_XYvals_ALLdata_JMP"
    
    fprintf('\n\nEvaluating Group... %s\n',WhichGroups{GROUPnow})

    % Call "Step0_UserInputData" m-file to retrieve user-supplied data
    [SpecimenList,~]=Step0_UserInputData(WhichGroups(GROUPnow));%2nd output, "VoxInterestList" is unused, so replaced by "~"

    %Sort "SpecimenList" for easy JMP import
    SpecimenList=sort(SpecimenList);
    
    for o=1:length(ObjInterestList)

        Object=ObjInterestList{o};

        %This Flag_{FS/AllDV} section MUST stay here at the start of the
        %object loop to reset the flags for each new object and maintain
        %compatibility with switching based on group alone.
        Flag_FS=0;
        Flag_AllDV=0;
        if (strcmpi(WhichGroups{GROUPnow},'Ctrl')==1) %catch Ctrl case (only AllDamage data is meaningful--no Failure Site exists for control specimens!)
            Flag_FS=1; %set flag to 1, meaning this data will not be saved later
        end
        
        %Catch different object cases
        if (strcmpi(ObjInterestList{o},'STAIN_EaClustRemvd')==1) %catch STAIN_EaClustRemvd object case
            %update "SpecficVersionNOW" to include the appended origin and study group for this loop
            SpecificVersionNOWload=strcat(VersionNumNOW,'DV',BinType,WhichGroups{GROUPnow});
            
        elseif (strcmpi(ObjInterestList{o},'lowMNRL_PV')==1) %catch lowMNRL_PV object case (only AllDamage data is meaningful)
            %update "SpecficVersionNOW" to include the appended origin and study group for this loop
            SpecificVersionNOWload=strcat(VersionNumNOW,'PV',BinType,WhichGroups{GROUPnow});
            
            Flag_FS=1;
        else
            %update "SpecficVersionNOW" to include the appended origin and study group for this loop
            SpecificVersionNOWload=strcat(VersionNumNOW,'DV',BinType,WhichGroups{GROUPnow});
        end

        fprintf('\tObject = %s\n',Object)

        file1a=strcat('PDF_',Object,'_FailSite_Xvals',SpecificVersionNOWload);
        file2a=strcat('PDF_',Object,'_FailSite_Yvals',SpecificVersionNOWload);
        file1b=strcat('PDF_',Object,'_AllDamage_Xvals',SpecificVersionNOWload);
        file2b=strcat('PDF_',Object,'_AllDamage_Yvals',SpecificVersionNOWload);
        load(strcat(LoadDirectory,file1a,'.mat'))
        load(strcat(LoadDirectory,file2a,'.mat'))
        load(strcat(LoadDirectory,file1b,'.mat'))
        load(strcat(LoadDirectory,file2b,'.mat'))
        eval(['PDF_FailSite_Xvals = ' file1a ';']);
        eval(['PDF_FailSite_Yvals = ' file2a ';']);
        eval(['PDF_AllDamage_Xvals = ' file1b ';']);
        eval(['PDF_AllDamage_Yvals = ' file2b ';']);
        clear('file1a','file1b','file2a','file2b');
        clearvars PDF_* -except PDF_FailSite_Xvals PDF_FailSite_Yvals PDF_AllDamage_Xvals PDF_AllDamage_Yvals

        Peak_XYvals_FailSite_ALL=cell(length(SpecimenList),4);
        Peak_XYvals_AllDamage_ALL=cell(length(SpecimenList),4);
        
        for s=1:length(SpecimenList)
            
            SpecimenNum=SpecimenList{s};
            fprintf('\t\tSpecimen Number = %s ...\n',SpecimenList{s})

            %locate the row associated with the max distance to search for peaks
            [rowD,~]=find(PDF_AllDamage_Xvals(:,s)==DistToSearch); % ~ character b/c no column info needed.  This row will be same for all others too.
            if (isempty(rowD))
                [rowDless,~]=find((PDF_FailSite_Xvals(:,s)>0) .* (PDF_FailSite_Xvals(:,s)<=DistToSearch));
                rowD=max(rowDless);
            end

            %search for peaks in PDF values
            Peak_Yval_FailSite=max(PDF_FailSite_Yvals(1:rowD,s));
            Peak_Yval_AllDamage=max(PDF_AllDamage_Yvals(1:rowD,s));

            %get corresponding distances (Xvals) of peak locations
            if ((isempty(Peak_Yval_FailSite)==0) && (isempty(Peak_Yval_AllDamage)==0)) %confirm that a peak has been identified
                Peak_Xval_FailSite=PDF_FailSite_Xvals(Peak_Yval_FailSite==PDF_FailSite_Yvals(:,s));
                Peak_Xval_AllDamage=PDF_AllDamage_Xvals(Peak_Yval_AllDamage==PDF_AllDamage_Yvals(:,s));
            else
                fprintf('\n\n\t\tA PDF peak value was not found for either FailSite and/or AllDamage\n\n!');
            end

            %store information for later save
            if (Flag_FS==1)
                Peak_XYvals_AllDamage_ALL{s,1}=SpecimenNum;
                Peak_XYvals_AllDamage_ALL{s,2}=horzcat(Object,'_AllDV');
                Peak_XYvals_AllDamage_ALL{s,3}=Peak_Xval_AllDamage;
                Peak_XYvals_AllDamage_ALL{s,4}=Peak_Yval_AllDamage;
            elseif (Flag_AllDV==1)
                Peak_XYvals_FailSite_ALL{s,1}=SpecimenNum;
                Peak_XYvals_FailSite_ALL{s,2}=horzcat(Object,'_FS');
                Peak_XYvals_FailSite_ALL{s,3}=Peak_Xval_FailSite;
                Peak_XYvals_FailSite_ALL{s,4}=Peak_Yval_FailSite;
            else
                Peak_XYvals_FailSite_ALL{s,1}=SpecimenNum;
                Peak_XYvals_FailSite_ALL{s,2}=horzcat(Object,'_FS');
                Peak_XYvals_FailSite_ALL{s,3}=Peak_Xval_FailSite;
                Peak_XYvals_FailSite_ALL{s,4}=Peak_Yval_FailSite;
                
                Peak_XYvals_AllDamage_ALL{s,1}=SpecimenNum;
                Peak_XYvals_AllDamage_ALL{s,2}=horzcat(Object,'_AllDV');
                Peak_XYvals_AllDamage_ALL{s,3}=Peak_Xval_AllDamage;
                Peak_XYvals_AllDamage_ALL{s,4}=Peak_Yval_AllDamage;
            end

            clear('SpecimenNum','RowD',...
                'Peak_Yval_FailSite','Peak_Yval_AllDamage',...
                'Peak_Xval_FailSite','Peak_Xval_AllDamage');
        end %end specimen loop

        %save data (Matlab files)
        if (strcmpi(WhichGroups{GROUPnow},'Ctrl')==1) %Control group specimens
            if (Flag_FS==1)
                SaveName1=strcat('Peak_XYvals_FailSite_ALL_',Object,'Ctrl');
                eval([SaveName1 '= Peak_XYvals_FailSite_ALL;']);
                save(strcat(SaveDirectory,SaveName1),SaveName1);
            elseif (Flag_AllDV==1)
            else
                SaveName1=strcat('Peak_XYvals_FailSite_ALL_',Object);
                SaveName2=strcat('Peak_XYvals_AllDamage_ALL_',Object);
                eval([SaveName1 '= Peak_XYvals_FailSite_ALL;']);
                eval([SaveName2 '= Peak_XYvals_AllDamage_ALL;']);
                save(strcat(SaveDirectory,SaveName1),SaveName1);
                save(strcat(SaveDirectory,SaveName2),SaveName2);
            end
            
        elseif (strcmpi(WhichGroups{GROUPnow},'Comp')==1) %Compression fatigue specimens
            if (Flag_FS==1)
                SaveName1=strcat('Peak_XYvals_FailSite_ALL_',Object,'Comp');
                eval([SaveName1 '= Peak_XYvals_FailSite_ALL;']);
                save(strcat(SaveDirectory,SaveName1),SaveName1);
            elseif (Flag_AllDV==1)
            else
                SaveName1=strcat('Peak_XYvals_FailSite_ALL_',Object,'Comp');
                SaveName2=strcat('Peak_XYvals_AllDamage_ALL_',Object,'Comp');
                eval([SaveName1 '= Peak_XYvals_FailSite_ALL;']);
                eval([SaveName2 '= Peak_XYvals_AllDamage_ALL;']);
                save(strcat(SaveDirectory,SaveName1),SaveName1);
                save(strcat(SaveDirectory,SaveName2),SaveName2);
            end
            
        elseif (strcmpi(WhichGroups{GROUPnow},'Tens')==1) %Tension fatigue specimens
            if (Flag_FS==1)
                SaveName1=strcat('Peak_XYvals_FailSite_ALL_',Object,'Tens');
                eval([SaveName1 '= Peak_XYvals_FailSite_ALL;']);
                save(strcat(SaveDirectory,SaveName1),SaveName1);
            elseif (Flag_AllDV==1)
            else
                SaveName1=strcat('Peak_XYvals_FailSite_ALL_',Object,'Tens');
                SaveName2=strcat('Peak_XYvals_AllDamage_ALL_',Object,'Tens');
                eval([SaveName1 '= Peak_XYvals_FailSite_ALL;']);
                eval([SaveName2 '= Peak_XYvals_AllDamage_ALL;']);
                save(strcat(SaveDirectory,SaveName1),SaveName1);
                save(strcat(SaveDirectory,SaveName2),SaveName2);
            end
        end

        %save all data (JMP import)
        if (Flag_FS==0)
            if (Trigger_Save==0);
                Peak_XYvals_ALLdata_JMP=Peak_XYvals_FailSite_ALL;
                Trigger_Save=1;
            else
                Peak_XYvals_ALLdata_JMP=vertcat(Peak_XYvals_ALLdata_JMP,Peak_XYvals_FailSite_ALL);
            end
        end

        if (Flag_AllDV==0)
            if (Trigger_Save==0);
                Peak_XYvals_ALLdata_JMP=Peak_XYvals_AllDamage_ALL;
                Trigger_Save=1;
            else
                Peak_XYvals_ALLdata_JMP=vertcat(Peak_XYvals_ALLdata_JMP,Peak_XYvals_AllDamage_ALL);
            end
        end

        clear('Object','SpecificVersionNOWload','PDF_FailSite_Xvals','PDF_FailSite_Yvals','PDF_AllDamage_Xvals','PDF_AllDamage_Yvals')
        clear('Peak_XYvals_FailSite_ALL','Peak_XYvals_AllDamage_ALL');
    end %end object loop

    %Complete JMP data saving process
    %set up column labels
    JMPdata_ColumnLabels={'CT Scan','Object&Site','Xval (mm)','Yval (PDF)'};

    %finalize by concatenating column labels to top of cell structures
    Peak_XYvals_ALLdata_JMP=vertcat(JMPdata_ColumnLabels,Peak_XYvals_ALLdata_JMP);

    %write to MS Excel file
    ExcelFileSaveName=strcat(SaveDirectory,'JMP_data_Peak_XYvals_ALLdata_',WhichGroups{GROUPnow},'.xlsx');
    [SuccessStatus,ErrMesg]=xlswrite(ExcelFileSaveName,Peak_XYvals_ALLdata_JMP);

    if (SuccessStatus==0)
        error('\n\nDid not save Excel file correctly!  See error message below...\n\n%s.',ErrMesg.message)
    end
    
    clear('SpecimenList','Peak_XYvals_ALLdata_JMP','ExcelFileSaveName');
end %end group loop

fprintf('\n\nProgram Execution Finished Successfully\n')
TotalTime=toc(StartTime);
TotalTimeMin=floor(TotalTime/60);
TotalTimeSec=round(((TotalTime/60)-TotalTimeMin)*60);
fprintf('Total time elapsed = %d min %d sec\n',TotalTimeMin,TotalTimeSec)



