function Step9a_PoreSizeCalculator_FailSitePore

%----- Input the desired specimens
WhichGroups={'Comp','Tens'}; %Options: "'Comp'" or "'Tens'" (i.e., any of the fatigue samples, that have a Fail Site location)

% Call "Step0_UserInputData" m-file to retrieve user-supplied data
[SpecimenList,VoxInterestList]=Step0_UserInputData(WhichGroups);

% Sort "SpecimenList" for easy JMP import
SpecimenList=sort(SpecimenList);

% Must also sort "VoxInterestList" since "SpecimenList" has been sorted!
VoxInterestList.Row=sortrows(VoxInterestList.Row,2);
VoxInterestList.Col=sortrows(VoxInterestList.Col,2);
VoxInterestList.Slice=sortrows(VoxInterestList.Slice,2);

FullISQdim_XYZ=[512 512 1166]; %used for failure site identification later in code
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

Slices_FailSitePore=cell(length(SpecimenList),2);
ClusterNumbers_FailSitePore=cell(length(SpecimenList),2);
Areas_FailSitePore=cell(length(SpecimenList),2);
AspectRatios_FailSitePore=cell(length(SpecimenList),2);
for s=1:length(SpecimenList)
    SpecimenNum=SpecimenList{s};
    Directory=strcat(SpecimenNum,'/');
    
    fprintf('Specimen Number = %s ...\n',SpecimenNum)
    
    % Retrieve AIM position and dimension data for current specimen
    PosAndDimsXYZ=open(strcat(Directory,'Images/',SpecimenNum,'_AIM_PositionAndDimension.mat'));
    Pos_XYZ=cell2mat(PosAndDimsXYZ.AIM_PositionAndDimension(1,1:3));
    Dim_XYZ=cell2mat(PosAndDimsXYZ.AIM_PositionAndDimension(2,1:3));
    clear('PosAndDimsXYZ');
    
    % Compute the failure site slice
    FailSiteSlice=(VoxInterestList.Slice{s,1}-Pos_XYZ(3));
    
    Object='PORES';
    LinearIndRUNL_file=strcat(Directory,'Images/',SpecimenNum,'_',Object,'_LinearIndexRUNL.mat');
    % call sub-function "LoadLinearIndRUNL"
    [SliceShow]=LoadLinearIndRUNL(LinearIndRUNL_file,Dim_XYZ,SpecimenNum,Object,FailSiteSlice);

    % Find connected pore clusters to label them and find their area and
    % ellipsoidal dimensions
    ConnectedPores=bwconncomp(SliceShow);
    LabelMatx=labelmatrix(ConnectedPores);
    ConnPoreInfo=regionprops(LabelMatx,'Area','MajorAxisLength','MinorAxisLength');
    
    % Retrieve the failure site damage and place those voxels on the image
    % as the brightest pixels (white)
    StainObject='STAIN_Peel10';
    LinearIndRUNL_file_stain=strcat(Directory,'Images/',SpecimenNum,'_',StainObject,'_LinearIndexRUNL.mat');
    % call sub-function "LoadLinearIndRUNL"
    [StainSlice]=LoadLinearIndRUNL(LinearIndRUNL_file_stain,Dim_XYZ,SpecimenNum,StainObject,FailSiteSlice);
    
    FailSiteLocation=[(FullISQdim_XYZ(2)-Pos_XYZ(2)-VoxInterestList.Row{s,1}),(VoxInterestList.Col{s,1}-Pos_XYZ(1))]; %(row,col)=(y,x)
    ConnectedStain=bwconncomp(StainSlice);
    LabelMatxStain=labelmatrix(ConnectedStain);
    
    StainClust=LabelMatxStain(FailSiteLocation(1),FailSiteLocation(2));
    
    SliceShow([ConnectedStain.PixelIdxList{StainClust}])=10;
    
    
    % Display the porosity image data as grey and the failure site damage
    % as a cluster of white pixels
    CurrFig=figure;
    imshow(SliceShow,([0 10]))
    
    % Have the user manually select the pore closest to the failure site
    % and record the X,Y (col,row) coordinates to be used to extract the
    % failure site pore cluster label from the "LabelMatx"
    fprintf('\n\tPlease click the figure ONCE on the \n\t pore CLOSEST to the failure site damage!\n\t(NOTE: Pores=grey, FailSiteDamage=white pixels)\n\n');
    [X_FailPore,Y_FailPore]=ginput(1);
    FailSitePoreClusterNumber=LabelMatx(round(Y_FailPore),round(X_FailPore)); %note, for indexing into LabelMatx (row,col)=(y,x)!
    
    % Confirm an appropriate FailSitePoreClusterNumber is obtained before
    % proceeding any further in code execution
    while (FailSitePoreClusterNumber==0)
        fprintf('WARNING: Initial user selection did not match a pore!\n\tPlease re-try failure site pore selection process...\n');
        
        % Have the user manually select the pore closest to the failure site
        % and record the X,Y (col,row) coordinates to be used to extract the
        % failure site pore cluster label from the "LabelMatx"
        fprintf('\n\tPlease click the figure ONCE on the \n\t pore CLOSEST to the failure site damage!\n\t(NOTE: Pores=grey, FailSiteDamage=white pixels)\n\n');
        [X_FailPore,Y_FailPore]=ginput(1);
        FailSitePoreClusterNumber=LabelMatx(round(Y_FailPore),round(X_FailPore)); %note, for indexing into LabelMatx (row,col)=(y,x)!
    end
    
    % Retrieve the failure site pore 'Slice', 'ClusterNumber', 'Area', 
    % and 'AspectRatio' and store for eventual save along with the
    % current specimen number
    Slices_FailSitePore(s,1:2)={SpecimenNum,FailSiteSlice};
    ClusterNumbers_FailSitePore(s,1:2)={SpecimenNum,FailSitePoreClusterNumber};
    Areas_FailSitePore(s,1:2)={SpecimenNum,ConnPoreInfo(FailSitePoreClusterNumber,1).Area};
    AspectRatios_FailSitePore(s,1:2)={SpecimenNum,ConnPoreInfo(FailSitePoreClusterNumber,1).MinorAxisLength / ConnPoreInfo(FailSitePoreClusterNumber,1).MajorAxisLength};
    
    close(CurrFig);
    clear('SpecimenNum','Directory','Pos_XYZ','Dim_XYZ','FailSiteSlice',...
        'LinearIndRUNL_file','ConnectedPores','LabelMatx','ConnPoreInfo',...
        'LinearIndRUNL_file_stain','StainSlice','FailSiteLocation',...
        'ConnectedStain','LabelMatxStain','StainClust','CurrFig',...
        'SliceShow','X_FailPore','Y_FailPore','FailSitePoreClusterNumber');
end %end specimen loop

% Save the data
SaveDirectory='PoreSize_Data/';
save(strcat(SaveDirectory,'Slices_FailSitePore'),'Slices_FailSitePore');
save(strcat(SaveDirectory,'ClusterNumbers_FailSitePore'),'ClusterNumbers_FailSitePore');
save(strcat(SaveDirectory,'Areas_FailSitePore'),'Areas_FailSitePore');
save(strcat(SaveDirectory,'AspectRatios_FailSitePore'),'AspectRatios_FailSitePore');

fprintf('\n\nProgram execution finished successfully!\n')

end %end main function




% Sub-function "LoadLinearIndRUNL"
%
function [OutputDataMatrix]=LoadLinearIndRUNL(Input_LinearIndRUNL,Dim_XYZ,SpecimenNum,ObjectNow,SliceNow)
    
    SliceVoxelsMAX=Dim_XYZ(1)*Dim_XYZ(2);%Xdim*Ydim;
    
    OutputDataMatrix=uint8([]);
    for slice=SliceNow %the failure site slice
        CurrentSlice=strcat('LinearIndexRUNL_',SpecimenNum,'_',ObjectNow,'_Slice',num2str(slice));
        LinearInd_SLICE=load(Input_LinearIndRUNL,'-mat',CurrentSlice);
        SliceData=LinearInd_SLICE.(CurrentSlice);
        
        LinearInd=zeros(SliceVoxelsMAX,1,'int8');
        if (isempty(SliceData) == 0) %"SliceData" must be non-empty to enter this loop
            for Row=1:1:length(SliceData(:,1))
                %{
                    For the statement below:
                        SliceData(Row,1) = linear index of starting voxel location
                        SliceData(Row,2) = number of extra voxels from the
                                            starting voxel location
                %}
                LinearInd(SliceData(Row,1):1:(SliceData(Row,1)+SliceData(Row,2)),1)=1;
            end
            
            OutputDataMatrix(:,:)=transpose(reshape(LinearInd,Dim_XYZ(1),Dim_XYZ(2)));
            %NOTE: the reshape command is correct as written to say Xdim,Ydim
            %since CT reads row-wise and Matlab orders column-wise, so the
            %shape is just trasposed, but then the "transpose()" command
            %corrects the data to be in the CT coordinate configuration for
            %use with the VoxInterestList values
        end
        
        clear('CurrentSlice','SliceData','LinearInd_SLICE')
    end
end %end of sub-function "LoadLinearIndRUNL"







